@@ -1,19 +1,19 @@
-/* 
-   Copyright (C) 2003-2008 FreeIPMI Core Team
+/*
+  Copyright (C) 2003-2009 FreeIPMI Core Team
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2, or (at your option)
+  any later version.
 
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.  
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, write to the Free Software Foundation,
+  Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 */
 
 #if HAVE_CONFIG_H
@@ -38,10 +38,10 @@ _enable_pef_checkout (const char *section_name,
                       void *arg)
 {
   bmc_config_state_data_t *state_data = (bmc_config_state_data_t *)arg;
-  return enable_pef_checkout(state_data->pstate,
-                             kv,
-                             state_data->ipmi_ctx, 
-                             &(state_data->prog_data->args->config_args));
+  return (enable_pef_checkout (state_data->pstate,
+                               kv,
+                               state_data->ipmi_ctx,
+                               &(state_data->prog_data->args->config_args)));
 }
 
 static config_err_t
@@ -50,10 +50,10 @@ _enable_pef_commit (const char *section_name,
                     void *arg)
 {
   bmc_config_state_data_t *state_data = (bmc_config_state_data_t *)arg;
-  return enable_pef_commit(state_data->pstate,
-                           kv, 
-                           state_data->ipmi_ctx, 
-                           &(state_data->prog_data->args->config_args));
+  return (enable_pef_commit (state_data->pstate,
+                             kv,
+                             state_data->ipmi_ctx,
+                             &(state_data->prog_data->args->config_args)));
 }
 
 static config_err_t
@@ -62,10 +62,10 @@ _enable_pef_event_messages_checkout (const char *section_name,
                                      void *arg)
 {
   bmc_config_state_data_t *state_data = (bmc_config_state_data_t *)arg;
-  return enable_pef_event_messages_checkout(state_data->pstate,
-                                            kv, 
-                                            state_data->ipmi_ctx, 
-                                            &(state_data->prog_data->args->config_args));
+  return (enable_pef_event_messages_checkout (state_data->pstate,
+                                              kv,
+                                              state_data->ipmi_ctx,
+                                              &(state_data->prog_data->args->config_args)));
 }
 
 static config_err_t
@@ -74,10 +74,10 @@ _enable_pef_event_messages_commit (const char *section_name,
                                    void *arg)
 {
   bmc_config_state_data_t *state_data = (bmc_config_state_data_t *)arg;
-  return enable_pef_event_messages_commit(state_data->pstate,
-                                          kv,
-                                          state_data->ipmi_ctx, 
-                                          &(state_data->prog_data->args->config_args));
+  return (enable_pef_event_messages_commit (state_data->pstate,
+                                            kv,
+                                            state_data->ipmi_ctx,
+                                            &(state_data->prog_data->args->config_args)));
 }
 
 static config_err_t
@@ -86,10 +86,10 @@ _enable_pef_startup_delay_checkout (const char *section_name,
                                     void *arg)
 {
   bmc_config_state_data_t *state_data = (bmc_config_state_data_t *)arg;
-  return enable_pef_startup_delay_checkout(state_data->pstate,
-                                           kv, 
-                                           state_data->ipmi_ctx, 
-                                           &(state_data->prog_data->args->config_args));
+  return (enable_pef_startup_delay_checkout (state_data->pstate,
+                                             kv,
+                                             state_data->ipmi_ctx,
+                                             &(state_data->prog_data->args->config_args)));
 }
 
 static config_err_t
@@ -98,10 +98,10 @@ _enable_pef_startup_delay_commit (const char *section_name,
                                   void *arg)
 {
   bmc_config_state_data_t *state_data = (bmc_config_state_data_t *)arg;
-  return enable_pef_startup_delay_commit(state_data->pstate,
-                                         kv, 
-                                         state_data->ipmi_ctx, 
-                                         &(state_data->prog_data->args->config_args));
+  return (enable_pef_startup_delay_commit (state_data->pstate,
+                                           kv,
+                                           state_data->ipmi_ctx,
+                                           &(state_data->prog_data->args->config_args)));
 }
 
 static config_err_t
@@ -110,10 +110,10 @@ _enable_pef_alert_startup_delay_checkout (const char *section_name,
                                           void *arg)
 {
   bmc_config_state_data_t *state_data = (bmc_config_state_data_t *)arg;
-  return enable_pef_alert_startup_delay_checkout(state_data->pstate,
-                                                 kv,
-                                                 state_data->ipmi_ctx,
-                                                 &(state_data->prog_data->args->config_args));
+  return (enable_pef_alert_startup_delay_checkout (state_data->pstate,
+                                                   kv,
+                                                   state_data->ipmi_ctx,
+                                                   &(state_data->prog_data->args->config_args)));
 }
 
 static config_err_t
@@ -122,10 +122,10 @@ _enable_pef_alert_startup_delay_commit (const char *section_name,
                                         void *arg)
 {
   bmc_config_state_data_t *state_data = (bmc_config_state_data_t *)arg;
-  return enable_pef_alert_startup_delay_commit(state_data->pstate,
-                                               kv, 
-                                               state_data->ipmi_ctx, 
-                                               &(state_data->prog_data->args->config_args));
+  return (enable_pef_alert_startup_delay_commit (state_data->pstate,
+                                                 kv,
+                                                 state_data->ipmi_ctx,
+                                                 &(state_data->prog_data->args->config_args)));
 }
 
 static config_err_t
@@ -134,10 +134,10 @@ _enable_alert_action_checkout (const char *section_name,
                                void *arg)
 {
   bmc_config_state_data_t *state_data = (bmc_config_state_data_t *)arg;
-  return enable_alert_action_checkout(state_data->pstate,
-                                      kv,
-                                      state_data->ipmi_ctx,
-                                      &(state_data->prog_data->args->config_args));
+  return (enable_alert_action_checkout (state_data->pstate,
+                                        kv,
+                                        state_data->ipmi_ctx,
+                                        &(state_data->prog_data->args->config_args)));
 }
 
 static config_err_t
@@ -146,10 +146,10 @@ _enable_alert_action_commit (const char *section_name,
                              void *arg)
 {
   bmc_config_state_data_t *state_data = (bmc_config_state_data_t *)arg;
-  return enable_alert_action_commit(state_data->pstate,
-                                    kv,
-                                    state_data->ipmi_ctx,
-                                    &(state_data->prog_data->args->config_args));
+  return (enable_alert_action_commit (state_data->pstate,
+                                      kv,
+                                      state_data->ipmi_ctx,
+                                      &(state_data->prog_data->args->config_args)));
 }
 
 static config_err_t
@@ -158,10 +158,10 @@ _enable_power_down_action_checkout (const char *section_name,
                                     void *arg)
 {
   bmc_config_state_data_t *state_data = (bmc_config_state_data_t *)arg;
-  return enable_power_down_action_checkout(state_data->pstate,
-                                           kv, 
-                                           state_data->ipmi_ctx, 
-                                           &(state_data->prog_data->args->config_args));
+  return (enable_power_down_action_checkout (state_data->pstate,
+                                             kv,
+                                             state_data->ipmi_ctx,
+                                             &(state_data->prog_data->args->config_args)));
 }
 
 static config_err_t
@@ -170,10 +170,10 @@ _enable_power_down_action_commit (const char *section_name,
                                   void *arg)
 {
   bmc_config_state_data_t *state_data = (bmc_config_state_data_t *)arg;
-  return enable_power_down_action_commit(state_data->pstate,
-                                         kv, 
-                                         state_data->ipmi_ctx, 
-                                         &(state_data->prog_data->args->config_args));
+  return (enable_power_down_action_commit (state_data->pstate,
+                                           kv,
+                                           state_data->ipmi_ctx,
+                                           &(state_data->prog_data->args->config_args)));
 }
 
 static config_err_t
@@ -182,10 +182,10 @@ _enable_reset_action_checkout (const char *section_name,
                                void *arg)
 {
   bmc_config_state_data_t *state_data = (bmc_config_state_data_t *)arg;
-  return enable_reset_action_checkout(state_data->pstate,
-                                      kv, 
-                                      state_data->ipmi_ctx, 
-                                      &(state_data->prog_data->args->config_args));
+  return (enable_reset_action_checkout (state_data->pstate,
+                                        kv,
+                                        state_data->ipmi_ctx,
+                                        &(state_data->prog_data->args->config_args)));
 }
 
 static config_err_t
@@ -194,10 +194,10 @@ _enable_reset_action_commit (const char *section_name,
                              void *arg)
 {
   bmc_config_state_data_t *state_data = (bmc_config_state_data_t *)arg;
-  return enable_reset_action_commit(state_data->pstate,
-                                    kv,
-                                    state_data->ipmi_ctx,
-                                    &(state_data->prog_data->args->config_args));
+  return (enable_reset_action_commit (state_data->pstate,
+                                      kv,
+                                      state_data->ipmi_ctx,
+                                      &(state_data->prog_data->args->config_args)));
 }
 
 static config_err_t
@@ -206,10 +206,10 @@ _enable_power_cycle_action_checkout (const char *section_name,
                                      void *arg)
 {
   bmc_config_state_data_t *state_data = (bmc_config_state_data_t *)arg;
-  return enable_power_cycle_action_checkout(state_data->pstate,
-                                            kv,
-                                            state_data->ipmi_ctx, 
-                                            &(state_data->prog_data->args->config_args));
+  return (enable_power_cycle_action_checkout (state_data->pstate,
+                                              kv,
+                                              state_data->ipmi_ctx,
+                                              &(state_data->prog_data->args->config_args)));
 }
 
 static config_err_t
@@ -218,10 +218,10 @@ _enable_power_cycle_action_commit (const char *section_name,
                                    void *arg)
 {
   bmc_config_state_data_t *state_data = (bmc_config_state_data_t *)arg;
-  return enable_power_cycle_action_commit(state_data->pstate,
-                                          kv,
-                                          state_data->ipmi_ctx, 
-                                          &(state_data->prog_data->args->config_args));
+  return (enable_power_cycle_action_commit (state_data->pstate,
+                                            kv,
+                                            state_data->ipmi_ctx,
+                                            &(state_data->prog_data->args->config_args)));
 }
 
 static config_err_t
@@ -230,10 +230,10 @@ _enable_oem_action_checkout (const char *section_name,
                              void *arg)
 {
   bmc_config_state_data_t *state_data = (bmc_config_state_data_t *)arg;
-  return enable_oem_action_checkout(state_data->pstate,
-                                    kv,
-                                    state_data->ipmi_ctx, 
-                                    &(state_data->prog_data->args->config_args));
+  return (enable_oem_action_checkout (state_data->pstate,
+                                      kv,
+                                      state_data->ipmi_ctx,
+                                      &(state_data->prog_data->args->config_args)));
 }
 
 static config_err_t
@@ -242,10 +242,10 @@ _enable_oem_action_commit (const char *section_name,
                            void *arg)
 {
   bmc_config_state_data_t *state_data = (bmc_config_state_data_t *)arg;
-  return enable_oem_action_commit(state_data->pstate,
-                                  kv,
-                                  state_data->ipmi_ctx, 
-                                  &(state_data->prog_data->args->config_args));
+  return (enable_oem_action_commit (state_data->pstate,
+                                    kv,
+                                    state_data->ipmi_ctx,
+                                    &(state_data->prog_data->args->config_args)));
 }
 
 static config_err_t
@@ -254,10 +254,10 @@ _enable_diagnostic_interrupt_checkout (const char *section_name,
                                        void *arg)
 {
   bmc_config_state_data_t *state_data = (bmc_config_state_data_t *)arg;
-  return enable_diagnostic_interrupt_checkout(state_data->pstate,
-                                              kv, 
-                                              state_data->ipmi_ctx, 
-                                              &(state_data->prog_data->args->config_args));
+  return (enable_diagnostic_interrupt_checkout (state_data->pstate,
+                                                kv,
+                                                state_data->ipmi_ctx,
+                                                &(state_data->prog_data->args->config_args)));
 }
 
 static config_err_t
@@ -266,10 +266,10 @@ _enable_diagnostic_interrupt_commit (const char *section_name,
                                      void *arg)
 {
   bmc_config_state_data_t *state_data = (bmc_config_state_data_t *)arg;
-  return enable_diagnostic_interrupt_commit(state_data->pstate,
-                                            kv, 
-                                            state_data->ipmi_ctx, 
-                                            &(state_data->prog_data->args->config_args));
+  return (enable_diagnostic_interrupt_commit (state_data->pstate,
+                                              kv,
+                                              state_data->ipmi_ctx,
+                                              &(state_data->prog_data->args->config_args)));
 }
 
 static config_err_t
@@ -278,10 +278,10 @@ _pef_startup_delay_checkout (const char *section_name,
                              void *arg)
 {
   bmc_config_state_data_t *state_data = (bmc_config_state_data_t *)arg;
-  return pef_startup_delay_checkout(state_data->pstate,
-                                    kv,
-                                    state_data->ipmi_ctx, 
-                                    &(state_data->prog_data->args->config_args));
+  return (pef_startup_delay_checkout (state_data->pstate,
+                                      kv,
+                                      state_data->ipmi_ctx,
+                                      &(state_data->prog_data->args->config_args)));
 }
 
 static config_err_t
@@ -290,10 +290,10 @@ _pef_startup_delay_commit (const char *section_name,
                            void *arg)
 {
   bmc_config_state_data_t *state_data = (bmc_config_state_data_t *)arg;
-  return pef_startup_delay_commit(state_data->pstate,
-                                  kv,
-                                  state_data->ipmi_ctx, 
-                                  &(state_data->prog_data->args->config_args));
+  return (pef_startup_delay_commit (state_data->pstate,
+                                    kv,
+                                    state_data->ipmi_ctx,
+                                    &(state_data->prog_data->args->config_args)));
 }
 
 static config_err_t
@@ -302,10 +302,10 @@ _pef_alert_startup_delay_checkout (const char *section_name,
                                    void *arg)
 {
   bmc_config_state_data_t *state_data = (bmc_config_state_data_t *)arg;
-  return pef_alert_startup_delay_checkout(state_data->pstate,
-                                          kv, 
-                                          state_data->ipmi_ctx, 
-                                          &(state_data->prog_data->args->config_args));
+  return (pef_alert_startup_delay_checkout (state_data->pstate,
+                                            kv,
+                                            state_data->ipmi_ctx,
+                                            &(state_data->prog_data->args->config_args)));
 }
 
 static config_err_t
@@ -314,28 +314,28 @@ _pef_alert_startup_delay_commit (const char *section_name,
                                  void *arg)
 {
   bmc_config_state_data_t *state_data = (bmc_config_state_data_t *)arg;
-  return pef_alert_startup_delay_commit(state_data->pstate,
-                                        kv, 
-                                        state_data->ipmi_ctx,
-                                        &(state_data->prog_data->args->config_args));
+  return (pef_alert_startup_delay_commit (state_data->pstate,
+                                          kv,
+                                          state_data->ipmi_ctx,
+                                          &(state_data->prog_data->args->config_args)));
 }
 
 struct config_section *
 bmc_config_pef_conf_section_get (bmc_config_state_data_t *state_data)
 {
-  struct config_section *pef_section;
+  struct config_section *section;
 
-  if (!(pef_section = config_section_create (state_data->pstate,
-                                             "PEF_Conf",
-                                             NULL,
-                                             NULL,
-                                             CONFIG_DO_NOT_CHECKOUT,
-                                             NULL,
-                                             NULL)))
+  if (!(section = config_section_create (state_data->pstate,
+                                         "PEF_Conf",
+                                         NULL,
+                                         NULL,
+                                         CONFIG_DO_NOT_CHECKOUT,
+                                         NULL,
+                                         NULL)))
     goto cleanup;
 
   if (config_section_add_key (state_data->pstate,
-                              pef_section,
+                              section,
                               "Enable_PEF",
                               "Possible values: Yes/No",
                               CONFIG_DO_NOT_CHECKOUT,
@@ -345,7 +345,7 @@ bmc_config_pef_conf_section_get (bmc_config_state_data_t *state_data)
     goto cleanup;
 
   if (config_section_add_key (state_data->pstate,
-                              pef_section,
+                              section,
                               "Enable_PEF_Event_Messages",
                               "Possible values: Yes/No",
                               CONFIG_DO_NOT_CHECKOUT,
@@ -355,7 +355,7 @@ bmc_config_pef_conf_section_get (bmc_config_state_data_t *state_data)
     goto cleanup;
 
   if (config_section_add_key (state_data->pstate,
-                              pef_section,
+                              section,
                               "Enable_PEF_Startup_Delay",
                               "Possible values: Yes/No",
                               CONFIG_DO_NOT_CHECKOUT,
@@ -365,7 +365,7 @@ bmc_config_pef_conf_section_get (bmc_config_state_data_t *state_data)
     goto cleanup;
 
   if (config_section_add_key (state_data->pstate,
-                              pef_section,
+                              section,
                               "Enable_PEF_Alert_Startup_Delay",
                               "Possible values: Yes/No",
                               CONFIG_DO_NOT_CHECKOUT,
@@ -373,9 +373,9 @@ bmc_config_pef_conf_section_get (bmc_config_state_data_t *state_data)
                               _enable_pef_alert_startup_delay_commit,
                               config_yes_no_validate) < 0)
     goto cleanup;
-  
+
   if (config_section_add_key (state_data->pstate,
-                              pef_section,
+                              section,
                               "Enable_Alert_Action",
                               "Possible values: Yes/No",
                               CONFIG_DO_NOT_CHECKOUT,
@@ -385,7 +385,7 @@ bmc_config_pef_conf_section_get (bmc_config_state_data_t *state_data)
     goto cleanup;
 
   if (config_section_add_key (state_data->pstate,
-                              pef_section,
+                              section,
                               "Enable_Power_Down_Action",
                               "Possible values: Yes/No",
                               CONFIG_DO_NOT_CHECKOUT,
@@ -395,7 +395,7 @@ bmc_config_pef_conf_section_get (bmc_config_state_data_t *state_data)
     goto cleanup;
 
   if (config_section_add_key (state_data->pstate,
-                              pef_section,
+                              section,
                               "Enable_Reset_Action",
                               "Possible values: Yes/No",
                               CONFIG_DO_NOT_CHECKOUT,
@@ -405,7 +405,7 @@ bmc_config_pef_conf_section_get (bmc_config_state_data_t *state_data)
     goto cleanup;
 
   if (config_section_add_key (state_data->pstate,
-                              pef_section,
+                              section,
                               "Enable_Power_Cycle_Action",
                               "Possible values: Yes/No",
                               CONFIG_DO_NOT_CHECKOUT,
@@ -415,7 +415,7 @@ bmc_config_pef_conf_section_get (bmc_config_state_data_t *state_data)
     goto cleanup;
 
   if (config_section_add_key (state_data->pstate,
-                              pef_section,
+                              section,
                               "Enable_OEM_Action",
                               "Possible values: Yes/No",
                               CONFIG_DO_NOT_CHECKOUT,
@@ -425,7 +425,7 @@ bmc_config_pef_conf_section_get (bmc_config_state_data_t *state_data)
     goto cleanup;
 
   if (config_section_add_key (state_data->pstate,
-                              pef_section,
+                              section,
                               "Enable_Diagnostic_Interrupt",
                               "Possible values: Yes/No",
                               CONFIG_DO_NOT_CHECKOUT,
@@ -435,7 +435,7 @@ bmc_config_pef_conf_section_get (bmc_config_state_data_t *state_data)
     goto cleanup;
 
   if (config_section_add_key (state_data->pstate,
-                              pef_section,
+                              section,
                               "PEF_Startup_Delay",
                               "Give value in seconds",
                               CONFIG_DO_NOT_CHECKOUT,
@@ -445,7 +445,7 @@ bmc_config_pef_conf_section_get (bmc_config_state_data_t *state_data)
     goto cleanup;
 
   if (config_section_add_key (state_data->pstate,
-                              pef_section,
+                              section,
                               "PEF_Alert_Startup_Delay",
                               "Give value in seconds",
                               CONFIG_DO_NOT_CHECKOUT,
@@ -454,11 +454,11 @@ bmc_config_pef_conf_section_get (bmc_config_state_data_t *state_data)
                               config_number_range_one_byte) < 0)
     goto cleanup;
 
-  return pef_section;
+  return (section);
 
  cleanup:
-  if (pef_section)
-    config_section_destroy(state_data->pstate, pef_section);
-  return NULL;
+  if (section)
+    config_section_destroy (state_data->pstate, section);
+  return (NULL);
 }
 
