@@ -1,19 +1,19 @@
-/* 
-   Copyright (C) 2003-2008 FreeIPMI Core Team
+/*
+  Copyright (C) 2003-2009 FreeIPMI Core Team
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2, or (at your option)
+  any later version.
 
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.  
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, write to the Free Software Foundation,
+  Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 */
 
 
@@ -62,6 +62,7 @@ typedef struct bmc_config_state_data
   bmc_config_prog_data_t *prog_data;
   ipmi_ctx_t ipmi_ctx;
   pstdout_state_t pstate;
+  struct config_section *sections;
 
   /* achu: workaround for IPMI limitation */
   int lan_user_session_limit_len;
@@ -73,26 +74,6 @@ typedef struct bmc_config_state_data
   int enable_user_after_password_len;
   bmc_config_enable_user_after_password_t *enable_user_after_password;
 
-  /* achu: workaround for OEM compliance issue, see lan_conf_auth section */
-  int lan_conf_auth_callback_level_oem_proprietary_set;
-  uint8_t lan_conf_auth_callback_level_oem_proprietary;
-  int lan_conf_auth_user_level_oem_proprietary_set;
-  uint8_t lan_conf_auth_user_level_oem_proprietary;
-  int lan_conf_auth_operator_level_oem_proprietary_set;
-  uint8_t lan_conf_auth_operator_level_oem_proprietary;
-  int lan_conf_auth_admin_level_oem_proprietary_set;
-  uint8_t lan_conf_auth_admin_level_oem_proprietary;
-  int lan_conf_auth_oem_level_none_set;
-  uint8_t lan_conf_auth_oem_level_none;
-  int lan_conf_auth_oem_level_md2_set;
-  uint8_t lan_conf_auth_oem_level_md2;
-  int lan_conf_auth_oem_level_md5_set;
-  uint8_t lan_conf_auth_oem_level_md5;
-  int lan_conf_auth_oem_level_straight_password_set;
-  uint8_t lan_conf_auth_oem_level_straight_password;
-  int lan_conf_auth_oem_level_oem_proprietary_set;
-  uint8_t lan_conf_auth_oem_level_oem_proprietary;
-
   /* achu: caching to make lan authentication enables go faster */
   int authentication_type_initialized;
   uint8_t authentication_type_none;
@@ -102,21 +83,21 @@ typedef struct bmc_config_state_data
   uint8_t authentication_type_oem_proprietary;
 
   /* achu: caching to make rmcpplus priv go faster */
-  int cipher_suite_entry_count;
-  int cipher_suite_id_supported[CIPHER_SUITE_LEN];
+  uint8_t cipher_suite_entry_count;
+  uint8_t cipher_suite_id_supported[CIPHER_SUITE_LEN];
   int cipher_suite_id_supported_set;
   uint8_t cipher_suite_priv[CIPHER_SUITE_LEN];
   int cipher_suite_priv_set;
 
   /* achu: caching to make bmc-config work more quickly */
   int lan_channel_number_initialized;
-  int8_t lan_channel_number;
+  uint8_t lan_channel_number;
   int serial_channel_number_initialized;
-  int8_t serial_channel_number;
+  uint8_t serial_channel_number;
   int sol_channel_number_initialized;
-  int8_t sol_channel_number;
+  uint8_t sol_channel_number;
   int number_of_users_initialized;
-  int8_t number_of_users;
+  uint8_t number_of_users;
 } bmc_config_state_data_t;
 
 #endif /* _BMC_CONFIG_H_ */
