@@ -219,18 +219,6 @@
 #define IPMI_OEM_FUJITSU_ERROR_LED_CSS_BLINK_GEL_ON    7
 #define IPMI_OEM_FUJITSU_ERROR_LED_CSS_BLINK_GEL_BLINK 8
 
-#define IPMI_IANA_ENTERPRISE_ID_FUJITSU               10368
-
-#define IPMI_NET_FN_OEM_FUJITSU_GENERIC_RQ 0x30
-#define IPMI_NET_FN_OEM_FUJITSU_GENERIC_RS 0x31
-
-#define IPMI_NET_FN_OEM_GROUP_RQ         0x2E
-#define IPMI_NET_FN_OEM_GROUP_RS         0x2F
-
-#define IPMI_CMD_OEM_FUJITSU_POWER         0x01
-#define IPMI_CMD_OEM_FUJITSU_SYSTEM        0xF5
-#define IPMI_CMD_OEM_FUJITSU_GET_REMOTE_STORAGE_CONNECTION_OR_STATUS 0x19
-
 static int
 _ipmi_oem_get_power_source (ipmi_oem_state_data_t *state_data,
                             uint8_t command_specifier,
@@ -287,7 +275,7 @@ _ipmi_oem_get_power_source (ipmi_oem_state_data_t *state_data,
       pstdout_fprintf (state_data->pstate,
                        stderr,
                        "ipmi_cmd_raw: %s\n",
-                       ipmi_ctx_strerror (ipmi_ctx_errnum (state_data->ipmi_ctx)));
+                       ipmi_ctx_errormsg (state_data->ipmi_ctx));
       goto cleanup;
     }
   
@@ -296,7 +284,8 @@ _ipmi_oem_get_power_source (ipmi_oem_state_data_t *state_data,
                                                    rs_len,
                                                    7,
                                                    IPMI_CMD_OEM_FUJITSU_POWER,
-                                                   IPMI_NET_FN_OEM_GROUP_RS) < 0)
+                                                   IPMI_NET_FN_OEM_GROUP_RS,
+                                                   NULL) < 0)
     goto cleanup;
 
   (*source) = bytes_rs[6];
@@ -519,7 +508,7 @@ ipmi_oem_fujitsu_get_remote_storage_status (ipmi_oem_state_data_t *state_data)
       pstdout_fprintf (state_data->pstate,
                        stderr,
                        "ipmi_cmd_raw: %s\n",
-                       ipmi_ctx_strerror (ipmi_ctx_errnum (state_data->ipmi_ctx)));
+                       ipmi_ctx_errormsg (state_data->ipmi_ctx));
       goto cleanup;
     }
   
@@ -528,7 +517,8 @@ ipmi_oem_fujitsu_get_remote_storage_status (ipmi_oem_state_data_t *state_data)
                                                    rs_len,
                                                    6,
                                                    IPMI_CMD_OEM_FUJITSU_GET_REMOTE_STORAGE_CONNECTION_OR_STATUS,
-                                                   IPMI_NET_FN_OEM_FUJITSU_GENERIC_RS) < 0)
+                                                   IPMI_NET_FN_OEM_FUJITSU_GENERIC_RS,
+                                                   NULL) < 0)
     goto cleanup;
 
   storage_status = bytes_rs[4];
@@ -685,7 +675,7 @@ ipmi_oem_fujitsu_get_system_status (ipmi_oem_state_data_t *state_data)
       pstdout_fprintf (state_data->pstate,
                        stderr,
                        "ipmi_cmd_raw: %s\n",
-                       ipmi_ctx_strerror (ipmi_ctx_errnum (state_data->ipmi_ctx)));
+                       ipmi_ctx_errormsg (state_data->ipmi_ctx));
       goto cleanup;
     }
   
@@ -694,7 +684,8 @@ ipmi_oem_fujitsu_get_system_status (ipmi_oem_state_data_t *state_data)
                                                    rs_len,
                                                    9,
                                                    IPMI_CMD_OEM_FUJITSU_SYSTEM,
-                                                   IPMI_NET_FN_OEM_GROUP_RS) < 0)
+                                                   IPMI_NET_FN_OEM_GROUP_RS,
+                                                   NULL) < 0)
     goto cleanup;
 
   /* achu: the "Notifications" are dependent on the timestamp input,
@@ -905,7 +896,7 @@ ipmi_oem_fujitsu_get_eeprom_version_info (ipmi_oem_state_data_t *state_data)
       pstdout_fprintf (state_data->pstate,
                        stderr,
                        "ipmi_cmd_raw: %s\n",
-                       ipmi_ctx_strerror (ipmi_ctx_errnum (state_data->ipmi_ctx)));
+                       ipmi_ctx_errormsg (state_data->ipmi_ctx));
       goto cleanup;
     }
   
@@ -914,7 +905,8 @@ ipmi_oem_fujitsu_get_eeprom_version_info (ipmi_oem_state_data_t *state_data)
                                                    rs_len,
                                                    21,
                                                    IPMI_CMD_OEM_FUJITSU_SYSTEM,
-                                                   IPMI_NET_FN_OEM_GROUP_RS) < 0)
+                                                   IPMI_NET_FN_OEM_GROUP_RS,
+                                                   NULL) < 0)
     goto cleanup;
 
   status = bytes_rs[5];
@@ -1044,7 +1036,7 @@ ipmi_oem_fujitsu_get_identify_led (ipmi_oem_state_data_t *state_data)
       pstdout_fprintf (state_data->pstate,
                        stderr,
                        "ipmi_cmd_raw: %s\n",
-                       ipmi_ctx_strerror (ipmi_ctx_errnum (state_data->ipmi_ctx)));
+                       ipmi_ctx_errormsg (state_data->ipmi_ctx));
       goto cleanup;
     }
   
@@ -1053,7 +1045,8 @@ ipmi_oem_fujitsu_get_identify_led (ipmi_oem_state_data_t *state_data)
                                                    rs_len,
                                                    6,
                                                    IPMI_CMD_OEM_FUJITSU_SYSTEM,
-                                                   IPMI_NET_FN_OEM_GROUP_RS) < 0)
+                                                   IPMI_NET_FN_OEM_GROUP_RS,
+                                                   NULL) < 0)
     goto cleanup;
 
   state = (bytes_rs[5] & IPMI_OEM_FUJITSU_IDENTIFY_LED_BITMASK);
@@ -1137,7 +1130,7 @@ ipmi_oem_fujitsu_set_identify_led (ipmi_oem_state_data_t *state_data)
       pstdout_fprintf (state_data->pstate,
                        stderr,
                        "ipmi_cmd_raw: %s\n",
-                       ipmi_ctx_strerror (ipmi_ctx_errnum (state_data->ipmi_ctx)));
+                       ipmi_ctx_errormsg (state_data->ipmi_ctx));
       goto cleanup;
     }
   
@@ -1146,7 +1139,8 @@ ipmi_oem_fujitsu_set_identify_led (ipmi_oem_state_data_t *state_data)
                                                    rs_len,
                                                    5,
                                                    IPMI_CMD_OEM_FUJITSU_SYSTEM,
-                                                   IPMI_NET_FN_OEM_GROUP_RS) < 0)
+                                                   IPMI_NET_FN_OEM_GROUP_RS,
+                                                   NULL) < 0)
     goto cleanup;
 
   rv = 0;
@@ -1219,7 +1213,7 @@ ipmi_oem_fujitsu_get_error_led (ipmi_oem_state_data_t *state_data)
       pstdout_fprintf (state_data->pstate,
                        stderr,
                        "ipmi_cmd_raw: %s\n",
-                       ipmi_ctx_strerror (ipmi_ctx_errnum (state_data->ipmi_ctx)));
+                       ipmi_ctx_errormsg (state_data->ipmi_ctx));
       goto cleanup;
     }
   
@@ -1228,7 +1222,8 @@ ipmi_oem_fujitsu_get_error_led (ipmi_oem_state_data_t *state_data)
                                                    rs_len,
                                                    6,
                                                    IPMI_CMD_OEM_FUJITSU_SYSTEM,
-                                                   IPMI_NET_FN_OEM_GROUP_RS) < 0)
+                                                   IPMI_NET_FN_OEM_GROUP_RS,
+                                                   NULL) < 0)
     goto cleanup;
 
   state = bytes_rs[5];
