@@ -80,11 +80,11 @@ ipmi_oem_supermicro_extra_firmware_info (ipmi_oem_state_data_t *state_data)
    * ? bytes - firmware tag, null terminated string
    */
 
-  bytes_rq[0] = 0x20;
+  bytes_rq[0] = IPMI_CMD_OEM_SUPERMICRO_EXTRA_FIRMWARE_INFO;
 
   if ((rs_len = ipmi_cmd_raw (state_data->ipmi_ctx,
                               0, /* lun */
-                              0x3C, /* network function */
+                              IPMI_NET_FN_OEM_SUPERMICRO_PEPPERCON_RQ, /* network function */
                               bytes_rq, /* data */
                               1, /* num bytes */
                               bytes_rs,
@@ -93,7 +93,7 @@ ipmi_oem_supermicro_extra_firmware_info (ipmi_oem_state_data_t *state_data)
       pstdout_fprintf (state_data->pstate,
                        stderr,
                        "ipmi_cmd_raw: %s\n",
-                       ipmi_ctx_strerror (ipmi_ctx_errnum (state_data->ipmi_ctx)));
+                       ipmi_ctx_errormsg (state_data->ipmi_ctx));
       goto cleanup;
     }
 
@@ -101,8 +101,9 @@ ipmi_oem_supermicro_extra_firmware_info (ipmi_oem_state_data_t *state_data)
                                                    bytes_rs,
                                                    rs_len,
                                                    19,
-                                                   0x20,
-                                                   0x3C) < 0)
+                                                   IPMI_CMD_OEM_SUPERMICRO_EXTRA_FIRMWARE_INFO,
+                                                   IPMI_NET_FN_OEM_SUPERMICRO_PEPPERCON_RS,
+                                                   NULL) < 0)
     goto cleanup;
 
   firmware_major_version = bytes_rs[2];
@@ -160,7 +161,7 @@ ipmi_oem_supermicro_reset_intrusion (ipmi_oem_state_data_t *state_data)
 {
   uint8_t bytes_rq[IPMI_OEM_MAX_BYTES];
   uint8_t bytes_rs[IPMI_OEM_MAX_BYTES];
-  int32_t rs_len;
+  int rs_len;
   int rv = -1;
 
   assert (state_data);
@@ -172,11 +173,11 @@ ipmi_oem_supermicro_reset_intrusion (ipmi_oem_state_data_t *state_data)
    * 0x03 - OEM cmd
    */
 
-  bytes_rq[0] = 0x03;
+  bytes_rq[0] = IPMI_CMD_OEM_SUPERMICRO_RESET_INTRUSION;
 
   if ((rs_len = ipmi_cmd_raw (state_data->ipmi_ctx,
                               0, /* lun */
-                              0x30, /* network function */
+                              IPMI_NET_FN_OEM_SUPERMICRO_GENERIC_RQ, /* network function */
                               bytes_rq, /* data */
                               1, /* num bytes */
                               bytes_rs,
@@ -185,7 +186,7 @@ ipmi_oem_supermicro_reset_intrusion (ipmi_oem_state_data_t *state_data)
       pstdout_fprintf (state_data->pstate,
                        stderr,
                        "ipmi_cmd_raw: %s\n",
-                       ipmi_ctx_strerror (ipmi_ctx_errnum (state_data->ipmi_ctx)));
+                       ipmi_ctx_errormsg (state_data->ipmi_ctx));
       goto cleanup;
     }
 
@@ -193,8 +194,9 @@ ipmi_oem_supermicro_reset_intrusion (ipmi_oem_state_data_t *state_data)
                                                    bytes_rs,
                                                    rs_len,
                                                    2,
-                                                   0x03,
-                                                   0x30) < 0)
+                                                   IPMI_CMD_OEM_SUPERMICRO_RESET_INTRUSION,
+                                                   IPMI_NET_FN_OEM_SUPERMICRO_GENERIC_RS,
+                                                   NULL) < 0)
     goto cleanup;
 
   rv = 0;
