@@ -1,25 +1,25 @@
 /*****************************************************************************\
- *  $Id: ipmiconsole.h,v 1.74.12.2 2009/11/05 17:41:11 chu11 Exp $
+ *  $Id: ipmiconsole.h,v 1.81 2009/11/05 17:41:19 chu11 Exp $
  *****************************************************************************
- *  Copyright (C) 2007-2008 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2009 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2006-2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Albert Chu <chu11@llnl.gov>
  *  UCRL-CODE-221226
- *  
+ *
  *  This file is part of Ipmiconsole, a set of IPMI 2.0 SOL libraries
  *  and utilities.  For details, see http://www.llnl.gov/linux/.
- *  
- *  Ipmiconsole is free software; you can redistribute it and/or modify 
- *  it under the terms of the GNU General Public License as published by the 
- *  Free Software Foundation; either version 2 of the License, or (at your 
+ *
+ *  Ipmiconsole is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by the
+ *  Free Software Foundation; either version 2 of the License, or (at your
  *  option) any later version.
- *  
- *  Ipmiconsole is distributed in the hope that it will be useful, but 
- *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
- *  or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License 
+ *
+ *  Ipmiconsole is distributed in the hope that it will be useful, but
+ *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ *  or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  *  for more details.
- *  
+ *
  *  You should have received a copy of the GNU General Public License along
  *  with Ipmiconsole.  If not, see <http://www.gnu.org/licenses/>.
 \*****************************************************************************/
@@ -34,7 +34,7 @@ extern "C" {
 #include <stdint.h>
 #include <freeipmi/freeipmi.h>
 
-/* 
+/*
  * IPMI Console Error Codes
  */
 #define IPMICONSOLE_ERR_SUCCESS                               0
@@ -45,7 +45,7 @@ extern "C" {
 #define IPMICONSOLE_ERR_CTX_NOT_SUBMITTED                     5
 #define IPMICONSOLE_ERR_CTX_IS_SUBMITTED                      6
 #define IPMICONSOLE_ERR_PARAMETERS                            7
-#define IPMICONSOLE_ERR_HOSTNAME_INVALID                      8 
+#define IPMICONSOLE_ERR_HOSTNAME_INVALID                      8
 #define IPMICONSOLE_ERR_IPMI_2_0_UNAVAILABLE                  9
 #define IPMICONSOLE_ERR_CIPHER_SUITE_ID_UNAVAILABLE          10
 #define IPMICONSOLE_ERR_USERNAME_INVALID                     11
@@ -71,7 +71,7 @@ extern "C" {
 #define IPMICONSOLE_ERR_INTERNAL_ERROR                       31
 #define IPMICONSOLE_ERR_ERRNUMRANGE                          32
 
-/* 
+/*
  * Debug Flags
  *
  * Utilized with ipmiconsole_engine_init() or with struct
@@ -84,7 +84,7 @@ extern "C" {
  * When used with struct ipmiconsole_engine_config and a context,
  * enables debugging specific to an IPMI connection with a specific
  * host.
- * 
+ *
  * STDOUT       - Output debugging to stdout
  * STDERR       - Output debugging to stderr
  * SYSLOG       - Output debugging to the Syslog
@@ -97,7 +97,7 @@ extern "C" {
 #define IPMICONSOLE_DEBUG_FILE             0x00000008
 #define IPMICONSOLE_DEBUG_IPMI_PACKETS     0x00000010
 
-/* 
+/*
  * IPMI Privilege Constants
  *
  * Utilized with struct ipmiconsole_ipmi_config below to specify a
@@ -105,49 +105,47 @@ extern "C" {
  */
 #define IPMICONSOLE_PRIVILEGE_USER                0
 #define IPMICONSOLE_PRIVILEGE_OPERATOR            1
-#define IPMICONSOLE_PRIVILEGE_ADMIN               2 
+#define IPMICONSOLE_PRIVILEGE_ADMIN               2
 
-/* 
+/*
  * Workaround Flags
  *
  * Utilized with struct ipmiconsole_ipmi_config below to specify
  * workarounds for specific motherboard manufacturers.
- * 
+ *
  * AUTHENTICATION_CAPABILITIES
  *
- * Discoverd on an ASUS P5M2 motherboard, the motherboard does not
- * properly report username capabilities or K_g status, leading to
- * invalid username or K_g errors.  This workaround flag will work
- * around the problem.  This problem is also confirmed on an ASUS
- * P5MT-R.
+ * This workaround flag will skip early checks for username
+ * capabilities, authentication capabilities, and K_g support and
+ * allow IPMI authentication to succeed.  It works around multiple
+ * issues in which the remote system does not properly report username
+ * capabilities, authentication capabilities, or K_g status.
  *
  * IGNORE_SOL_PAYLOAD_SIZE
  *
- * Discovered on an ASUS P5M2 motherboard, the motherboard reports
- * invalid SOL payload sizes.  This workaround flag will ignore the
- * payload size and choose a reasonable default.
+ * This workaround flag will not check for valid SOL payload sizes and
+ * assume a proper set.  It works around remote systems that report
+ * invalid IPMI 2.0 SOL payload sizes.
  *
  * IGNORE_SOL_PORT
  *
- * Discovered on an ASUS P5MT-R motherboard, the motherboard reports
- * an invalid SOL port.  This workaround flag will ignore the invalid
- * port and continue with the default.
+ * This workaround flag will ignore alternate SOL ports specified
+ * during the protocol.  It works around remote systems that report
+ * invalid alternate SOL ports.
  *
  * SKIP_SOL_ACTIVATION_STATUS
  *
- * Discovered on Supermicro X8SIL-F motherboard, the motherboard does
- * not support the Get Payload Activation Status command.  This
- * workaround flag will skip that portion of the protocol and pray for
- * the best.
+ * This workaround flag will not check the current activation status
+ * of SOL during the protocol setup.  It works around remote systems
+ * that do not properly support this command.
  *
  * INTEL_2_0_SESSION
  *
- * All currently known IPMI 2.0 implementations on Intel motherboards
- * contain a number of authentication bugs.  They include username
- * padding bugs, RAKP 4 integrity check values calculation bugs, and
- * password truncation if the authentication algorithm is
- * HMAC-MD5-128.  This workaround flag will allow the library to
- * authenticate with an Intel motherboard.
+ * This workaround flag will work around several Intel IPMI 2.0
+ * authentication issues.  The issues covered include padding of
+ * usernames, automatic acceptance of a RAKP 4 response integrity
+ * check when using the integrity algorithm MD5-128, and password
+ * truncation if the authentication algorithm is HMAC-MD5-128.
  *
  * Security Note: When the Integrity Algorithm is MD5-128 (Cipher
  * Suite ID 11 & 12), the integrity check value of a RAKP 4 packet
@@ -158,16 +156,25 @@ extern "C" {
  *
  * SUPERMICRO_2_0_SESSION
  *
- * There are several small IPMI compliance issues on early Supermicro
- * IPMI SOL implementations.  Most involve the authentication codes
- * returned during the RAKP2 portion of authentication.  This
- * workaround flag will get around the problem.  These compliance bugs
- * are confirmed to be fixed on newer firmware.
+ * This workaround flag will work around several early Supermicro IPMI
+ * 2.0 authentication issues.  The issues covered include handling
+ * invalid length authentication codes.
  *
  * SUN_2_0_SESSION
  *
- * Work around several IPMI 2.0 compliance problems, mostly involving
- * invalid lengthed hash keys and unsupported payload types.
+ * This workaround flag will work work around several Sun IPMI 2.0
+ * authentication issues.  The issues covered include invalid lengthed
+ * hash keys, improperly hashed keys, and invalid cipher suite
+ * records.
+ *
+ * OPEN_SESSION_PRIVILEGE
+ * 
+ * This workaround flag will slightly alter FreeIPMI's IPMI 2.0
+ * connection protocol to workaround an invalid hashing algorithm used
+ * by the remote system.  The privilege level sent during the Open
+ * Session stage of an IPMI 2.0 connection is used for hashing keys
+ * instead of the privilege level sent during the RAKP1 connection
+ * stage.
  *
  * Note: The non-logical bitmask order below is set for consistency of
  * masks with libfreeipmi bitmasks.
@@ -180,13 +187,13 @@ extern "C" {
 #define IPMICONSOLE_WORKAROUND_SUPERMICRO_2_0_SESSION      0x02000000
 #define IPMICONSOLE_WORKAROUND_SUN_2_0_SESSION             0x04000000
 #define IPMICONSOLE_WORKAROUND_OPEN_SESSION_PRIVILEGE      0x08000000
-       
-/* 
+
+/*
  * Engine Flags
  *
  * Utilized with struct ipmiconsole_engine_config below to alter
  * libipmiconsole engine behavior.
- * 
+ *
  * CLOSE_FD
  *
  * By default, the ipmiconsole engine will not close the file
@@ -228,12 +235,12 @@ extern "C" {
 #define IPMICONSOLE_ENGINE_OUTPUT_ON_SOL_ESTABLISHED 0x00000002
 #define IPMICONSOLE_ENGINE_LOCK_MEMORY               0x00000004
 
-/* 
+/*
  * Behavior Flags
  *
  * Utilized with struct ipmiconsole_protocol_config below to atler
  * SOL connection behavior.
- * 
+ *
  * ERROR_ON_SOL_INUSE
  *
  * Under most circumstances, if SOL is detected as being in use,
@@ -245,7 +252,7 @@ extern "C" {
  * SOL is already detected as being in use.  If it is detected as in
  * use, the errnum returned from ipmiconsole_ctx_errnum() would be
  * IPMICONSOLE_ERR_SOL_INUSE.
- *   
+ *
  * DEACTIVATE_ONLY
  *
  * Only attempt to deactivate the SOL session.  If an SOL session is
@@ -262,7 +269,7 @@ extern "C" {
  * ERROR
  *
  * An error has occurred retrieving the status.
- * 
+ *
  * NOT_SUBMITTED
  *
  * The context has not been submitted to the engine.
@@ -282,21 +289,21 @@ extern "C" {
  *
  */
 enum ipmiconsole_ctx_status
-  {
-    IPMICONSOLE_CTX_STATUS_ERROR = -1,
-    IPMICONSOLE_CTX_STATUS_NOT_SUBMITTED = 0,
-    IPMICONSOLE_CTX_STATUS_SUBMITTED = 1,
-    IPMICONSOLE_CTX_STATUS_SOL_ERROR = 2,
-    IPMICONSOLE_CTX_STATUS_SOL_ESTABLISHED = 3,
-  };
+{
+  IPMICONSOLE_CTX_STATUS_ERROR = -1,
+  IPMICONSOLE_CTX_STATUS_NOT_SUBMITTED = 0,
+  IPMICONSOLE_CTX_STATUS_SUBMITTED = 1,
+  IPMICONSOLE_CTX_STATUS_SOL_ERROR = 2,
+  IPMICONSOLE_CTX_STATUS_SOL_ESTABLISHED = 3,
+};
 typedef enum ipmiconsole_ctx_status ipmiconsole_ctx_status_t;
 
-/* 
+/*
  * ipmiconsole_ipmi_config
  *
  * IPMI configuration for a connection to a remote IPMI machine.
  *
- * username 
+ * username
  *
  *   BMC username. Pass NULL ptr for NULL username.  Maximum length of
  *   16 bytes.
@@ -318,7 +325,7 @@ typedef enum ipmiconsole_ctx_status ipmiconsole_ctx_status_t;
  *
  * privilege_level
  *
- *   privilege level to authenticate with.  
+ *   privilege level to authenticate with.
  *
  *   Supported privilege levels:
  *
@@ -357,7 +364,7 @@ typedef enum ipmiconsole_ctx_status ipmiconsole_ctx_status_t;
  *   for correct operation. Pass 0 for default of no modifications to
  *   the IPMI protocol.
  */
-struct ipmiconsole_ipmi_config 
+struct ipmiconsole_ipmi_config
 {
   char *username;
   char *password;
@@ -368,10 +375,10 @@ struct ipmiconsole_ipmi_config
   unsigned int workaround_flags;
 };
 
-/* 
+/*
  * ipmiconsole_protocol_config
  *
- * Configuration information for the IPMI protocol management. 
+ * Configuration information for the IPMI protocol management.
  *
  * session_timeout_len
  *
@@ -404,7 +411,7 @@ struct ipmiconsole_ipmi_config
  *   Specifies the maximum number of consecutive packet errors that
  *   can be received from a remote BMC before an error is returned and
  *   the session ended.  Pass <= 0 to use the default of 16.
- * 
+ *
  *   Note: This has been added to the behavior of the IPMI engine due
  *   to issues where remote BMCs can become "un-synced" with sequence
  *   numbers due to a network kernel boot.  It is possible a stream of
@@ -436,7 +443,7 @@ struct ipmiconsole_protocol_config
   int maximum_retransmission_count;
 };
 
-/* 
+/*
  * ipmiconsole_engine_config
  *
  * Configuration information for how the engine should interact with
@@ -462,7 +469,7 @@ struct ipmiconsole_protocol_config
 struct ipmiconsole_engine_config
 {
   unsigned int engine_flags;
-  unsigned int behavior_flags; 
+  unsigned int behavior_flags;
   unsigned int debug_flags;
 };
 
@@ -470,7 +477,7 @@ struct ipmiconsole_engine_config
 
 typedef struct ipmiconsole_ctx *ipmiconsole_ctx_t;
 
-/* 
+/*
  * Ipmiconsole_callback
  *
  * Function prototype for a callback function.
@@ -478,7 +485,7 @@ typedef struct ipmiconsole_ctx *ipmiconsole_ctx_t;
  */
 typedef void (*Ipmiconsole_callback)(void *);
 
-/* 
+/*
  * ipmiconsole_engine_init
  *
  * Initialize the ipmiconsole engine.  Engine threads will be created
@@ -489,20 +496,21 @@ typedef void (*Ipmiconsole_callback)(void *);
  * Parameters:
  *
  * thread_count
- * 
+ *
  *   Number of threads the engine will support.
  *
- * debug_flags 
+ * debug_flags
  *
  *   Bitwise OR of flags indicating how debug output should (or should
  *   not) be output. Pass 0 for default of no debugging.
  *
- * Returns 0 on success, -1 on error
+ * Returns 0 on success, -1 on error.  On error errno will be set to
+ * indicate error.
  */
-int ipmiconsole_engine_init(unsigned int thread_count, 
-			    unsigned int debug_flags);
+int ipmiconsole_engine_init (unsigned int thread_count,
+                             unsigned int debug_flags);
 
-/* 
+/*
  * ipmiconsole_engine_submit
  *
  * Submit a context to the ipmiconsole engine non-blocking.  This
@@ -548,7 +556,7 @@ int ipmiconsole_engine_init(unsigned int thread_count,
  * Parameters:
  *
  * callback
- *  
+ *
  *   If specified, a callback function will be called from the engine
  *   when a SOL session has been established or a SOL establishment
  *   error has occurred.  Will only be called under a non-blocking
@@ -568,13 +576,14 @@ int ipmiconsole_engine_init(unsigned int thread_count,
  *   routine.  If the callback will be required to process the context
  *   status, the context should be included in this argument.
  *
- * Returns 0 on success, -1 on error.  
+ * Returns 0 on success, -1 on error.  ipmiconsole_ctx_errnum() can be
+ * called to determine the cause of the error.
  */
-int ipmiconsole_engine_submit(ipmiconsole_ctx_t c,
-                              Ipmiconsole_callback callback,
-                              void *callback_arg);
+int ipmiconsole_engine_submit (ipmiconsole_ctx_t c,
+                               Ipmiconsole_callback callback,
+                               void *callback_arg);
 
-/* 
+/*
  * ipmiconsole_engine_submit_block
  *
  * Submit a context to the ipmiconsole engine and block until a SOL
@@ -583,11 +592,12 @@ int ipmiconsole_engine_submit(ipmiconsole_ctx_t c,
  * an error occurred.  On an error, ipmiconsole_ctx_errnum() can be
  * used to determine the type of error that occured.
  *
- * Returns 0 on success, -1 on error.  
+ * Returns 0 on success, -1 on error.  ipmiconsole_ctx_errnum() can be
+ * called to determine the cause of the error.
  */
-int ipmiconsole_engine_submit_block(ipmiconsole_ctx_t c);
+int ipmiconsole_engine_submit_block (ipmiconsole_ctx_t c);
 
-/* 
+/*
  * ipmiconsole_engine_teardown
  *
  * Teardown the ipmiconsole engine.  This function will destroy
@@ -601,9 +611,9 @@ int ipmiconsole_engine_submit_block(ipmiconsole_ctx_t c);
  *   ipmiconsole_engine_teardown() will block until all active ipmi
  *   sessions have been closed cleanly or timed out.
  */
-void ipmiconsole_engine_teardown(int cleanup_sol_sessions);
+void ipmiconsole_engine_teardown (int cleanup_sol_sessions);
 
-/* 
+/*
  * ipmiconsole_ctx_create
  *
  * Create a ipmiconsole context.  The context can then be submitted
@@ -634,40 +644,49 @@ void ipmiconsole_engine_teardown(int cleanup_sol_sessions);
  *   Ipmiconsole engine configuration.  See ipmiconsole_engine_config
  *   definition above.
  *
- * Returns ctx on success, NULL on error.
+ * Returns ctx on success, NULL on error.  On error errno will be set to
+ * indicate error.
  */
-ipmiconsole_ctx_t ipmiconsole_ctx_create(char *hostname,
-					 struct ipmiconsole_ipmi_config *ipmi_config,
-					 struct ipmiconsole_protocol_config *protocol_config,
-					 struct ipmiconsole_engine_config *engine_config);
+ipmiconsole_ctx_t ipmiconsole_ctx_create (const char *hostname,
+                                          struct ipmiconsole_ipmi_config *ipmi_config,
+                                          struct ipmiconsole_protocol_config *protocol_config,
+                                          struct ipmiconsole_engine_config *engine_config);
 
-/* 
+/*
  * ipmiconsole_ctx_errnum
  *
  * Returns the errnum of the most recently recorded error for the
  * context that has not yet been read by the user.
  */
-int ipmiconsole_ctx_errnum(ipmiconsole_ctx_t c);
+int ipmiconsole_ctx_errnum (ipmiconsole_ctx_t c);
 
-/* 
+/*
  * ipmiconsole_ctx_strerror
  *
  * Returns a pointer to statically allocated string describing the
  * error code in errnum.
  */
-char *ipmiconsole_ctx_strerror(int errnum);
+char *ipmiconsole_ctx_strerror (int errnum);
 
-/* 
+/*
+ * ipmiconsole_ctx_errormsg
+ *
+ * Returns a pointer to statically allocated string describing the
+ * most recent error for the context.
+ */
+char *ipmiconsole_ctx_errormsg (ipmiconsole_ctx_t c);
+
+/*
  * ipmiconsole_ctx_status
  *
  * Returns the current context status.  Primarily used to determine if
  * a context submission (submitted non-blocking via
  * ipmiconsole_engine_submit()) has been established or not.  Returns
- * IPMICONSOLE_CTX_STATUS_ERROR (-1) on error.  
+ * IPMICONSOLE_CTX_STATUS_ERROR (-1) on error.
  */
-ipmiconsole_ctx_status_t ipmiconsole_ctx_status(ipmiconsole_ctx_t c);
+ipmiconsole_ctx_status_t ipmiconsole_ctx_status (ipmiconsole_ctx_t c);
 
-/* 
+/*
  * ipmiconsole_ctx_fd
  *
  * Returns a file descriptor for console reading and writing after it
@@ -687,9 +706,9 @@ ipmiconsole_ctx_status_t ipmiconsole_ctx_status(ipmiconsole_ctx_t c);
  * write().  For alternate file descriptor behavior, see ENGINE flags
  * above.
  */
-int ipmiconsole_ctx_fd(ipmiconsole_ctx_t c);
+int ipmiconsole_ctx_fd (ipmiconsole_ctx_t c);
 
-/* 
+/*
  * ipmiconsole_ctx_generate_break
  *
  * Generate a break on an active serial over LAN session.
@@ -697,15 +716,15 @@ int ipmiconsole_ctx_fd(ipmiconsole_ctx_t c);
  * Returns 0 on success, -1 on error.  ipmiconsole_ctx_errnum() can be
  * called to determine the cause of the error.
  */
-int ipmiconsole_ctx_generate_break(ipmiconsole_ctx_t c);
+int ipmiconsole_ctx_generate_break (ipmiconsole_ctx_t c);
 
-/* 
+/*
  * ipmiconsole_ctx_destroy
  *
  * Destroy a context.  Will close file descriptor retrieved from
  * ipmiconsole_ctx_fd().
  */
-void ipmiconsole_ctx_destroy(ipmiconsole_ctx_t c);
+void ipmiconsole_ctx_destroy (ipmiconsole_ctx_t c);
 
 #ifdef __cplusplus
 }
