@@ -1,25 +1,25 @@
 /*****************************************************************************\
- *  $Id: ipmiconsole_garbage_collector.c,v 1.17 2008/06/07 16:09:55 chu11 Exp $
+ *  $Id: ipmiconsole_garbage_collector.c,v 1.20 2009/03/04 19:41:29 chu11 Exp $
  *****************************************************************************
- *  Copyright (C) 2007-2008 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2009 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2006-2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Albert Chu <chu11@llnl.gov>
  *  UCRL-CODE-221226
- *  
+ *
  *  This file is part of Ipmiconsole, a set of IPMI 2.0 SOL libraries
  *  and utilities.  For details, see http://www.llnl.gov/linux/.
- *  
- *  Ipmiconsole is free software; you can redistribute it and/or modify 
- *  it under the terms of the GNU General Public License as published by the 
- *  Free Software Foundation; either version 2 of the License, or (at your 
+ *
+ *  Ipmiconsole is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by the
+ *  Free Software Foundation; either version 2 of the License, or (at your
  *  option) any later version.
- *  
- *  Ipmiconsole is distributed in the hope that it will be useful, but 
- *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
- *  or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License 
+ *
+ *  Ipmiconsole is distributed in the hope that it will be useful, but
+ *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ *  or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  *  for more details.
- *  
+ *
  *  You should have received a copy of the GNU General Public License along
  *  with Ipmiconsole.  If not, see <http://www.gnu.org/licenses/>.
 \*****************************************************************************/
@@ -66,7 +66,7 @@ extern int garbage_collector_notifier[2];
 #define IPMICONSOLE_GARBAGE_COLLECTOR_SPIN_TIME 30
 
 void *
-ipmiconsole_garbage_collector(void *arg)
+ipmiconsole_garbage_collector (void *arg)
 {
   while (1)
     {
@@ -77,13 +77,13 @@ ipmiconsole_garbage_collector(void *arg)
       int n;
       fd_set rds;
 
-      FD_ZERO(&rds);
-      FD_SET(garbage_collector_notifier[0], &rds);
+      FD_ZERO (&rds);
+      FD_SET (garbage_collector_notifier[0], &rds);
 
       tv.tv_sec = IPMICONSOLE_GARBAGE_COLLECTOR_SPIN_TIME;
       tv.tv_usec = 0;
-      
-      /* What happens if anythings fails?  
+
+      /* What happens if anythings fails?
        *
        * Quit - well that's bad.
        *
@@ -92,16 +92,16 @@ ipmiconsole_garbage_collector(void *arg)
        * For now, just log.
        */
 
-      if ((n = select(garbage_collector_notifier[0] + 1, &rds, NULL, NULL, &tv)) < 0)
+      if ((n = select (garbage_collector_notifier[0] + 1, &rds, NULL, NULL, &tv)) < 0)
         {
-          IPMICONSOLE_DEBUG(("select: %s", strerror(errno)));
+          IPMICONSOLE_DEBUG (("select: %s", strerror (errno)));
           continue;
         }
 
       /* Signal from ipmiconsole_engine_teardown() to quit */
-      if (n && FD_ISSET(garbage_collector_notifier[0], &rds))
+      if (n && FD_ISSET (garbage_collector_notifier[0], &rds))
         break;
-      
+
       /* Note: the code in __ipmiconsole_ctx_connection_cleanup() and
        * ipmiconsole_garbage_collector() may look like it may race and
        * could deadlock.  (ABBA and BAAB deadlock situation).  However,
@@ -114,19 +114,19 @@ ipmiconsole_garbage_collector(void *arg)
        * functions.
        */
 
-      if ((perr = pthread_mutex_lock(&(console_engine_ctxs_to_destroy_mutex))) != 0)
-        IPMICONSOLE_DEBUG(("pthread_mutex_lock: %s", strerror(perr)));
+      if ((perr = pthread_mutex_lock (&(console_engine_ctxs_to_destroy_mutex))) != 0)
+        IPMICONSOLE_DEBUG (("pthread_mutex_lock: %s", strerror (perr)));
 
-      if (!(itr = list_iterator_create(console_engine_ctxs_to_destroy)))
+      if (!(itr = list_iterator_create (console_engine_ctxs_to_destroy)))
         {
-          IPMICONSOLE_DEBUG(("list_iterator_create: %s", strerror(errno)));
+          IPMICONSOLE_DEBUG (("list_iterator_create: %s", strerror (errno)));
           goto end_loop;
         }
-      
-      while ((c = (ipmiconsole_ctx_t)list_next(itr)))
+
+      while ((c = (ipmiconsole_ctx_t)list_next (itr)))
         {
-          if ((perr = pthread_mutex_lock(&(c->signal.destroyed_mutex))) != 0)
-            IPMICONSOLE_DEBUG(("pthread_mutex_lock: %s", strerror(perr)));
+          if ((perr = pthread_mutex_lock (&(c->signal.destroyed_mutex))) != 0)
+            IPMICONSOLE_DEBUG (("pthread_mutex_lock: %s", strerror (perr)));
 
           /* Be careful, if the user requested to destroy the context, we can
            * destroy it here.  But if we destroy it, there is no mutex to
@@ -134,23 +134,23 @@ ipmiconsole_garbage_collector(void *arg)
            */
           if (c->signal.user_has_destroyed)
             {
-              if (!list_delete(itr))
-                IPMICONSOLE_DEBUG(("list_delete: %s", strerror(errno)));
+              if (!list_delete (itr))
+                IPMICONSOLE_DEBUG (("list_delete: %s", strerror (errno)));
             }
           else
             {
-              if ((perr = pthread_mutex_unlock(&(c->signal.destroyed_mutex))) != 0)
-                IPMICONSOLE_DEBUG(("pthread_mutex_unlock: %s", strerror(perr)));
+              if ((perr = pthread_mutex_unlock (&(c->signal.destroyed_mutex))) != 0)
+                IPMICONSOLE_DEBUG (("pthread_mutex_unlock: %s", strerror (perr)));
             }
         }
 
-      if ((perr = pthread_mutex_unlock(&(console_engine_ctxs_to_destroy_mutex))) != 0)
-        IPMICONSOLE_DEBUG(("pthread_mutex_unlock: %s", strerror(perr)));
+      if ((perr = pthread_mutex_unlock (&(console_engine_ctxs_to_destroy_mutex))) != 0)
+        IPMICONSOLE_DEBUG (("pthread_mutex_unlock: %s", strerror (perr)));
 
     end_loop:
       if (itr)
-        list_iterator_destroy(itr);
+        list_iterator_destroy (itr);
     }
 
-  return NULL;
+  return (NULL);
 }
