@@ -1,7 +1,7 @@
 /*****************************************************************************\
- *  $Id: ipmi_monitoring_ipmi_communication.c,v 1.22.4.2 2009/06/04 17:12:14 chu11 Exp $
+ *  $Id: ipmi_monitoring_ipmi_communication.c,v 1.35 2009/07/31 17:18:13 chu11 Exp $
  *****************************************************************************
- *  Copyright (C) 2007-2008 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2009 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2006-2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Albert Chu <chu11@llnl.gov>
@@ -45,7 +45,6 @@
 #include "ipmi_monitoring.h"
 #include "ipmi_monitoring_defs.h"
 #include "ipmi_monitoring_debug.h"
-#include "ipmi_monitoring_fiid_wrappers.h"
 #include "ipmi_monitoring_ipmi_communication.h"
 
 #include "freeipmi-portability.h"
@@ -53,29 +52,29 @@
 extern uint32_t _ipmi_monitoring_flags;
 
 static void
-_ipmi_communication_cleanup(ipmi_monitoring_ctx_t c)
+_ipmi_communication_cleanup (ipmi_monitoring_ctx_t c)
 {
-  assert(c);
-  assert(c->magic == IPMI_MONITORING_MAGIC);
+  assert (c);
+  assert (c->magic == IPMI_MONITORING_MAGIC);
 
   if (c->ipmi_ctx)
     {
-      ipmi_ctx_close(c->ipmi_ctx);
-      ipmi_ctx_destroy(c->ipmi_ctx);
+      ipmi_ctx_close (c->ipmi_ctx);
+      ipmi_ctx_destroy (c->ipmi_ctx);
       c->ipmi_ctx = NULL;
     }
 }
 
 static int
-_inband_init(ipmi_monitoring_ctx_t c,
-             struct ipmi_monitoring_ipmi_config *config)
+_inband_init (ipmi_monitoring_ctx_t c,
+              struct ipmi_monitoring_ipmi_config *config)
 {
   unsigned int workaround_flags;
   unsigned int flags;
 
-  assert(c);
-  assert(c->magic == IPMI_MONITORING_MAGIC);
-  assert(c->ipmi_ctx);
+  assert (c);
+  assert (c->magic == IPMI_MONITORING_MAGIC);
+  assert (c->ipmi_ctx);
 
   if (config
       && ((config->driver_type >= 0
@@ -86,15 +85,15 @@ _inband_init(ipmi_monitoring_ctx_t c,
           || (config->workaround_flags)))
     {
       c->errnum = IPMI_MONITORING_ERR_PARAMETERS;
-      return -1;
+      return (-1);
     }
-  
+
   workaround_flags = 0;
   if (config && config->workaround_flags)
     {
       /* No inband workarounds supported right now */
     }
-  
+
   if ((_ipmi_monitoring_flags & IPMI_MONITORING_FLAGS_DEBUG)
       && (_ipmi_monitoring_flags & IPMI_MONITORING_FLAGS_DEBUG_IPMI_PACKETS))
     flags = IPMI_FLAGS_DEBUG_DUMP;
@@ -103,70 +102,44 @@ _inband_init(ipmi_monitoring_ctx_t c,
 
   if (!config || config->driver_type < 0)
     {
-      if (ipmi_ctx_open_inband (c->ipmi_ctx,
-                                IPMI_DEVICE_SUNBMC,
-                                (config) ? config->disable_auto_probe : 0,
-                                (config) ? config->driver_address : 0,
-                                (config) ? config->register_spacing : 0,
-                                (config) ? config->driver_device : NULL,
-                                workaround_flags,
-                                flags) < 0)
+      int ret;
+
+      if ((ret = ipmi_ctx_find_inband (c->ipmi_ctx,
+                                       NULL,
+                                       (config) ? config->disable_auto_probe : 0,
+                                       (config) ? config->driver_address : 0,
+                                       (config) ? config->register_spacing : 0,
+                                       (config) ? config->driver_device : NULL,
+                                       workaround_flags,
+                                       flags)) < 0)
         {
-          if (ipmi_ctx_open_inband (c->ipmi_ctx,
-                                    IPMI_DEVICE_OPENIPMI,
-                                    (config) ? config->disable_auto_probe : 0,
-                                    (config) ? config->driver_address : 0,
-                                    (config) ? config->register_spacing : 0,
-                                    (config) ? config->driver_device : NULL,
-                                    workaround_flags,
-                                    flags) < 0)
-            {
-              IPMI_MONITORING_DEBUG(("ipmi_cmd: %s", ipmi_ctx_strerror(ipmi_ctx_errnum(c->ipmi_ctx))));
-              
-              if (ipmi_ctx_open_inband (c->ipmi_ctx,
-                                        IPMI_DEVICE_KCS,
-                                        (config) ? config->disable_auto_probe : 0,
-                                        (config) ? config->driver_address : 0,
-                                        (config) ? config->register_spacing : 0,
-                                        (config) ? config->driver_device : NULL,
-                                        workaround_flags,
-                                        flags) < 0)
-                {
-                  IPMI_MONITORING_DEBUG(("ipmi_cmd: %s", ipmi_ctx_strerror(ipmi_ctx_errnum(c->ipmi_ctx))));
-                  
-                  if (ipmi_ctx_open_inband (c->ipmi_ctx,
-                                            IPMI_DEVICE_SSIF,
-                                            (config) ? config->disable_auto_probe : 0,
-                                            (config) ? config->driver_address : 0,
-                                            (config) ? config->register_spacing : 0,
-                                            (config) ? config->driver_device : NULL,
-                                            workaround_flags,
-                                            flags) < 0)
-                    {
-                      IPMI_MONITORING_DEBUG(("ipmi_cmd: %s", ipmi_ctx_strerror(ipmi_ctx_errnum(c->ipmi_ctx))));
-                      
-                      if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_BMC_BUSY)
-                        c->errnum = IPMI_MONITORING_ERR_BMC_BUSY;
-                      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE_INVALID_COMMAND
-                               || ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE_REQUEST_DATA_INVALID
-                               || ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE
-                               || ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_IPMI_ERROR)
-                        c->errnum = IPMI_MONITORING_ERR_IPMI_ERROR;
-                      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_OUT_OF_MEMORY)
-                        c->errnum = IPMI_MONITORING_ERR_OUT_OF_MEMORY;
-                      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_SYSTEM_ERROR
-                               || ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_DEVICE_NOT_FOUND)
-                        c->errnum = IPMI_MONITORING_ERR_SYSTEM_ERROR;
-                      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_DRIVER_PATH_REQUIRED)
-                        c->errnum = IPMI_MONITORING_ERR_PARAMETERS;
-                      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_DRIVER_TIMEOUT)
-                        c->errnum = IPMI_MONITORING_ERR_SYSTEM_ERROR;
-                      else
-                        c->errnum = IPMI_MONITORING_ERR_INTERNAL_ERROR;
-                      return -1;
-                    }
-                }
-            } 
+          IPMI_MONITORING_DEBUG (("ipmi_ctx_find_inband: %s", ipmi_ctx_errormsg (c->ipmi_ctx)));
+
+          if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_BMC_BUSY)
+            c->errnum = IPMI_MONITORING_ERR_BMC_BUSY;
+          else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE
+                   || ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_IPMI_ERROR)
+            c->errnum = IPMI_MONITORING_ERR_IPMI_ERROR;
+          else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_OUT_OF_MEMORY)
+            c->errnum = IPMI_MONITORING_ERR_OUT_OF_MEMORY;
+          else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_SYSTEM_ERROR
+                   || ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_DEVICE_NOT_FOUND)
+            c->errnum = IPMI_MONITORING_ERR_SYSTEM_ERROR;
+          else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_DRIVER_PATH_REQUIRED)
+            c->errnum = IPMI_MONITORING_ERR_PARAMETERS;
+          else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_DRIVER_TIMEOUT)
+            c->errnum = IPMI_MONITORING_ERR_SYSTEM_ERROR;
+          else
+            c->errnum = IPMI_MONITORING_ERR_INTERNAL_ERROR;
+          return (-1);
+        }
+
+      if (!ret)
+        {
+          /* SYSTEM_ERROR? or INTERNAL_ERROR? Hmmmm */
+          IPMI_MONITORING_DEBUG (("ipmi_ctx_find_inband: %s", ipmi_ctx_errormsg (c->ipmi_ctx)));
+          c->errnum = IPMI_MONITORING_ERR_SYSTEM_ERROR;
+          return (-1);
         }
     }
   else
@@ -184,42 +157,40 @@ _inband_init(ipmi_monitoring_ctx_t c,
 
       if (ipmi_ctx_open_inband (c->ipmi_ctx,
                                 driver_type,
-                                (config) ? config->disable_auto_probe : 0,
-                                (config) ? config->driver_address : 0,
-                                (config) ? config->register_spacing : 0,
-                                (config) ? config->driver_device : NULL,
+                                config->disable_auto_probe,
+                                config->driver_address,
+                                config->register_spacing,
+                                config->driver_device,
                                 workaround_flags,
                                 flags) < 0)
         {
-          IPMI_MONITORING_DEBUG(("ipmi_cmd: %s", ipmi_ctx_strerror(ipmi_ctx_errnum(c->ipmi_ctx))));
+          IPMI_MONITORING_DEBUG (("ipmi_ctx_open_inband: %s", ipmi_ctx_errormsg (c->ipmi_ctx)));
 
-          if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_BMC_BUSY)
+          if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_BMC_BUSY)
             c->errnum = IPMI_MONITORING_ERR_BMC_BUSY;
-          else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE_INVALID_COMMAND
-                   || ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE_REQUEST_DATA_INVALID
-                   || ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE
-                   || ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_IPMI_ERROR)
+          else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE
+                   || ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_IPMI_ERROR)
             c->errnum = IPMI_MONITORING_ERR_IPMI_ERROR;
-          else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_OUT_OF_MEMORY)
+          else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_OUT_OF_MEMORY)
             c->errnum = IPMI_MONITORING_ERR_OUT_OF_MEMORY;
-          else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_SYSTEM_ERROR
-                   || ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_DEVICE_NOT_FOUND)
+          else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_SYSTEM_ERROR
+                   || ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_DEVICE_NOT_FOUND)
             c->errnum = IPMI_MONITORING_ERR_SYSTEM_ERROR;
-          else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_DRIVER_PATH_REQUIRED)
+          else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_DRIVER_PATH_REQUIRED)
             c->errnum = IPMI_MONITORING_ERR_PARAMETERS;
           else
             c->errnum = IPMI_MONITORING_ERR_INTERNAL_ERROR;
-          return -1;
+          return (-1);
         }
     }
 
-  return 0;
+  return (0);
 }
-             
+
 static int
-_ipmi_1_5_init(ipmi_monitoring_ctx_t c, 
-               const char *hostname,
-               struct ipmi_monitoring_ipmi_config *config)
+_ipmi_1_5_init (ipmi_monitoring_ctx_t c,
+                const char *hostname,
+                struct ipmi_monitoring_ipmi_config *config)
 {
   uint8_t privilege_level;
   uint8_t authentication_type;
@@ -233,15 +204,15 @@ _ipmi_1_5_init(ipmi_monitoring_ctx_t c,
                                         | IPMI_MONITORING_WORKAROUND_FLAGS_BIG_ENDIAN_SEQUENCE_NUMBER
                                         | IPMI_MONITORING_WORKAROUND_FLAGS_AUTHENTICATION_CAPABILITIES);
 
-  assert(c);
-  assert(c->magic == IPMI_MONITORING_MAGIC);
-  assert(c->ipmi_ctx);
-  assert(hostname);
+  assert (c);
+  assert (c->magic == IPMI_MONITORING_MAGIC);
+  assert (c->ipmi_ctx);
+  assert (hostname);
 
-  if (strlen(hostname) > MAXHOSTNAMELEN
+  if (strlen (hostname) > MAXHOSTNAMELEN
       || (config
-          && ((config->username && strlen(config->username) > IPMI_MAX_USER_NAME_LENGTH)
-              || (config->password && strlen(config->password) > IPMI_1_5_MAX_PASSWORD_LENGTH)
+          && ((config->username && strlen (config->username) > IPMI_MAX_USER_NAME_LENGTH)
+              || (config->password && strlen (config->password) > IPMI_1_5_MAX_PASSWORD_LENGTH)
               || (config->privilege_level >= 0
                   && (config->privilege_level != IPMI_MONITORING_PRIVILEGE_LEVEL_USER
                       && config->privilege_level != IPMI_MONITORING_PRIVILEGE_LEVEL_OPERATOR
@@ -254,7 +225,7 @@ _ipmi_1_5_init(ipmi_monitoring_ctx_t c,
               || (config->workaround_flags & ~workaround_flags_mask))))
     {
       c->errnum = IPMI_MONITORING_ERR_PARAMETERS;
-      return -1;
+      return (-1);
     }
 
   if (config && config->privilege_level >= 0)
@@ -296,7 +267,7 @@ _ipmi_1_5_init(ipmi_monitoring_ctx_t c,
   if (retransmission_timeout_len > session_timeout_len)
     {
       c->errnum = IPMI_MONITORING_ERR_PARAMETERS;
-      return -1;
+      return (-1);
     }
 
   workaround_flags = 0;
@@ -313,13 +284,13 @@ _ipmi_1_5_init(ipmi_monitoring_ctx_t c,
       if (config->workaround_flags & IPMI_MONITORING_WORKAROUND_FLAGS_AUTHENTICATION_CAPABILITIES)
         workaround_flags |= IPMI_WORKAROUND_FLAGS_AUTHENTICATION_CAPABILITIES;
     }
-  
+
   if ((_ipmi_monitoring_flags & IPMI_MONITORING_FLAGS_DEBUG)
       && (_ipmi_monitoring_flags & IPMI_MONITORING_FLAGS_DEBUG_IPMI_PACKETS))
     flags = IPMI_FLAGS_DEBUG_DUMP;
   else
     flags = IPMI_FLAGS_DEFAULT;
-  
+
   if (ipmi_ctx_open_outofband (c->ipmi_ctx,
                                hostname,
                                (config) ? config->username : NULL,
@@ -331,48 +302,46 @@ _ipmi_1_5_init(ipmi_monitoring_ctx_t c,
                                workaround_flags,
                                flags) < 0)
     {
-      IPMI_MONITORING_DEBUG(("ipmi_ctx_open_outofband: %s", ipmi_ctx_strerror(ipmi_ctx_errnum(c->ipmi_ctx))));
-      if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_USERNAME_INVALID)
+      IPMI_MONITORING_DEBUG (("ipmi_ctx_open_outofband: %s", ipmi_ctx_errormsg (c->ipmi_ctx)));
+      if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_USERNAME_INVALID)
         c->errnum = IPMI_MONITORING_ERR_USERNAME_INVALID;
-      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_PASSWORD_INVALID)
+      else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_PASSWORD_INVALID)
         c->errnum = IPMI_MONITORING_ERR_PASSWORD_INVALID;
-      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_PRIVILEGE_LEVEL_INSUFFICIENT)
+      else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_PRIVILEGE_LEVEL_INSUFFICIENT)
         c->errnum = IPMI_MONITORING_ERR_PRIVILEGE_LEVEL_INSUFFICIENT;
-      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_PRIVILEGE_LEVEL_CANNOT_BE_OBTAINED)
+      else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_PRIVILEGE_LEVEL_CANNOT_BE_OBTAINED)
         c->errnum = IPMI_MONITORING_ERR_PRIVILEGEL_LEVEL_CANNOT_BE_OBTAINED;
-      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_AUTHENTICATION_TYPE_UNAVAILABLE)
+      else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_AUTHENTICATION_TYPE_UNAVAILABLE)
         c->errnum = IPMI_MONITORING_ERR_AUTHENTICATION_TYPE_UNAVAILABLE;
-      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_PASSWORD_VERIFICATION_TIMEOUT)
+      else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_PASSWORD_VERIFICATION_TIMEOUT)
         c->errnum = IPMI_MONITORING_ERR_PASSWORD_VERIFICATION_TIMEOUT;
-      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_SESSION_TIMEOUT)
+      else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_SESSION_TIMEOUT)
         c->errnum = IPMI_MONITORING_ERR_SESSION_TIMEOUT;
-      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE_INVALID_COMMAND
-               || ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE_REQUEST_DATA_INVALID
-               || ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE
-               || ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_IPMI_ERROR)
+      else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE
+               || ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_IPMI_ERROR)
         c->errnum = IPMI_MONITORING_ERR_IPMI_ERROR;
-      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_BMC_BUSY)
+      else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_BMC_BUSY)
         c->errnum = IPMI_MONITORING_ERR_BMC_BUSY;
-      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_OUT_OF_MEMORY)
+      else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_OUT_OF_MEMORY)
         c->errnum = IPMI_MONITORING_ERR_OUT_OF_MEMORY;
-      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_HOSTNAME_INVALID)
+      else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_HOSTNAME_INVALID)
         c->errnum = IPMI_MONITORING_ERR_HOSTNAME_INVALID;
-      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_PARAMETERS)
+      else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_PARAMETERS)
         c->errnum = IPMI_MONITORING_ERR_PARAMETERS;
-      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_SYSTEM_ERROR)
+      else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_SYSTEM_ERROR)
         c->errnum = IPMI_MONITORING_ERR_SYSTEM_ERROR;
       else
         c->errnum = IPMI_MONITORING_ERR_INTERNAL_ERROR;
-      return -1;
+      return (-1);
     }
 
-  return 0;
+  return (0);
 }
 
 static int
-_ipmi_2_0_init(ipmi_monitoring_ctx_t c, 
-               const char *hostname,
-               struct ipmi_monitoring_ipmi_config *config)
+_ipmi_2_0_init (ipmi_monitoring_ctx_t c,
+                const char *hostname,
+                struct ipmi_monitoring_ipmi_config *config)
 {
   uint8_t privilege_level;
   uint8_t cipher_suite_id;
@@ -385,15 +354,15 @@ _ipmi_2_0_init(ipmi_monitoring_ctx_t c,
                                     | IPMI_MONITORING_WORKAROUND_FLAGS_SUPERMICRO_2_0_SESSION
                                     | IPMI_MONITORING_WORKAROUND_FLAGS_SUN_2_0_SESSION
                                     | IPMI_MONITORING_WORKAROUND_FLAGS_OPEN_SESSION_PRIVILEGE);
-  assert(c);
-  assert(c->magic == IPMI_MONITORING_MAGIC);
-  assert(c->ipmi_ctx);
-  assert(hostname);
+  assert (c);
+  assert (c->magic == IPMI_MONITORING_MAGIC);
+  assert (c->ipmi_ctx);
+  assert (hostname);
 
-  if (strlen(hostname) > MAXHOSTNAMELEN
+  if (strlen (hostname) > MAXHOSTNAMELEN
       || (config
-          && ((config->username && strlen(config->username) > IPMI_MAX_USER_NAME_LENGTH)
-              || (config->password && strlen(config->password) > IPMI_2_0_MAX_PASSWORD_LENGTH)
+          && ((config->username && strlen (config->username) > IPMI_MAX_USER_NAME_LENGTH)
+              || (config->password && strlen (config->password) > IPMI_2_0_MAX_PASSWORD_LENGTH)
               || (config->k_g && config->k_g_len > IPMI_MAX_K_G_LENGTH)
               || (config->privilege_level >= 0
                   && (config->privilege_level != IPMI_MONITORING_PRIVILEGE_LEVEL_USER
@@ -412,7 +381,7 @@ _ipmi_2_0_init(ipmi_monitoring_ctx_t c,
               || (config->workaround_flags & ~workaround_flags_mask))))
     {
       c->errnum = IPMI_MONITORING_ERR_PARAMETERS;
-      return -1;
+      return (-1);
     }
 
   if (config && config->privilege_level >= 0)
@@ -445,7 +414,7 @@ _ipmi_2_0_init(ipmi_monitoring_ctx_t c,
   if (retransmission_timeout_len > session_timeout_len)
     {
       c->errnum = IPMI_MONITORING_ERR_PARAMETERS;
-      return -1;
+      return (-1);
     }
 
   workaround_flags = 0;
@@ -462,7 +431,7 @@ _ipmi_2_0_init(ipmi_monitoring_ctx_t c,
       if (config->workaround_flags & IPMI_MONITORING_WORKAROUND_FLAGS_OPEN_SESSION_PRIVILEGE)
         workaround_flags |= IPMI_WORKAROUND_FLAGS_OPEN_SESSION_PRIVILEGE;
     }
-  
+
   if ((_ipmi_monitoring_flags & IPMI_MONITORING_FLAGS_DEBUG)
       && (_ipmi_monitoring_flags & IPMI_MONITORING_FLAGS_DEBUG_IPMI_PACKETS))
     flags = IPMI_FLAGS_DEBUG_DUMP;
@@ -482,155 +451,151 @@ _ipmi_2_0_init(ipmi_monitoring_ctx_t c,
                                    workaround_flags,
                                    flags) < 0)
     {
-      IPMI_MONITORING_DEBUG(("ipmi_ctx_open_outofband_2_0: %s", ipmi_ctx_strerror(ipmi_ctx_errnum(c->ipmi_ctx))));
-      if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_USERNAME_INVALID)
+      IPMI_MONITORING_DEBUG (("ipmi_ctx_open_outofband_2_0: %s", ipmi_ctx_errormsg (c->ipmi_ctx)));
+      if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_USERNAME_INVALID)
         c->errnum = IPMI_MONITORING_ERR_USERNAME_INVALID;
-      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_PASSWORD_INVALID)
+      else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_PASSWORD_INVALID)
         c->errnum = IPMI_MONITORING_ERR_PASSWORD_INVALID;
-      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_PRIVILEGE_LEVEL_INSUFFICIENT)
+      else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_PRIVILEGE_LEVEL_INSUFFICIENT)
         c->errnum = IPMI_MONITORING_ERR_PRIVILEGE_LEVEL_INSUFFICIENT;
-      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_PRIVILEGE_LEVEL_CANNOT_BE_OBTAINED)
+      else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_PRIVILEGE_LEVEL_CANNOT_BE_OBTAINED)
         c->errnum = IPMI_MONITORING_ERR_PRIVILEGEL_LEVEL_CANNOT_BE_OBTAINED;
-      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_K_G_INVALID)
+      else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_K_G_INVALID)
         c->errnum = IPMI_MONITORING_ERR_K_G_INVALID;
-      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_CIPHER_SUITE_ID_UNAVAILABLE)
+      else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_CIPHER_SUITE_ID_UNAVAILABLE)
         c->errnum = IPMI_MONITORING_ERR_CIPHER_SUITE_ID_UNAVAILABLE;
-      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_PASSWORD_VERIFICATION_TIMEOUT)
+      else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_PASSWORD_VERIFICATION_TIMEOUT)
         c->errnum = IPMI_MONITORING_ERR_PASSWORD_VERIFICATION_TIMEOUT;
-      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_IPMI_2_0_UNAVAILABLE)
+      else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_IPMI_2_0_UNAVAILABLE)
         c->errnum = IPMI_MONITORING_ERR_IPMI_2_0_UNAVAILABLE;
-      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_SESSION_TIMEOUT)
+      else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_SESSION_TIMEOUT)
         c->errnum = IPMI_MONITORING_ERR_SESSION_TIMEOUT;
-      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE_INVALID_COMMAND
-               || ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE_REQUEST_DATA_INVALID
-               || ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE
-               || ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_IPMI_ERROR)
+      else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE
+               || ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_IPMI_ERROR)
         c->errnum = IPMI_MONITORING_ERR_IPMI_ERROR;
-      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_BMC_BUSY)
+      else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_BMC_BUSY)
         c->errnum = IPMI_MONITORING_ERR_BMC_BUSY;
-      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_OUT_OF_MEMORY)
+      else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_OUT_OF_MEMORY)
         c->errnum = IPMI_MONITORING_ERR_OUT_OF_MEMORY;
-      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_HOSTNAME_INVALID)
+      else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_HOSTNAME_INVALID)
         c->errnum = IPMI_MONITORING_ERR_HOSTNAME_INVALID;
-      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_PARAMETERS)
+      else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_PARAMETERS)
         c->errnum = IPMI_MONITORING_ERR_PARAMETERS;
-      else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_SYSTEM_ERROR)
+      else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_SYSTEM_ERROR)
         c->errnum = IPMI_MONITORING_ERR_SYSTEM_ERROR;
       else
         c->errnum = IPMI_MONITORING_ERR_INTERNAL_ERROR;
-      return -1;
+      return (-1);
     }
 
-  return 0;
+  return (0);
 }
 
 static int
-_outofband_init(ipmi_monitoring_ctx_t c, 
-                const char *hostname,
-                struct ipmi_monitoring_ipmi_config *config)
+_outofband_init (ipmi_monitoring_ctx_t c,
+                 const char *hostname,
+                 struct ipmi_monitoring_ipmi_config *config)
 {
-  assert(c);
-  assert(c->magic == IPMI_MONITORING_MAGIC);
-  assert(c->ipmi_ctx);
-  assert(hostname);
+  assert (c);
+  assert (c->magic == IPMI_MONITORING_MAGIC);
+  assert (c->ipmi_ctx);
+  assert (hostname);
 
-  if (strlen(hostname) > MAXHOSTNAMELEN
+  if (strlen (hostname) > MAXHOSTNAMELEN
       || (config
           && ((config->protocol_version >= 0
                && (config->protocol_version != IPMI_MONITORING_PROTOCOL_VERSION_1_5
                    && config->protocol_version != IPMI_MONITORING_PROTOCOL_VERSION_2_0)))))
     {
       c->errnum = IPMI_MONITORING_ERR_PARAMETERS;
-      return -1;
+      return (-1);
     }
 
-  if (!config 
+  if (!config
       || config->protocol_version < 0
       || config->protocol_version == IPMI_MONITORING_PROTOCOL_VERSION_1_5)
     {
-      if (_ipmi_1_5_init(c,
-                         hostname,
-                         config) < 0)
-        return -1;
+      if (_ipmi_1_5_init (c,
+                          hostname,
+                          config) < 0)
+        return (-1);
     }
   else
     {
-      if (_ipmi_2_0_init(c,
-                         hostname,
-                         config) < 0)
-        return -1;
+      if (_ipmi_2_0_init (c,
+                          hostname,
+                          config) < 0)
+        return (-1);
     }
 
-  return 0;
+  return (0);
 }
 
-int 
-ipmi_monitoring_ipmi_communication_init(ipmi_monitoring_ctx_t c,
-                                        const char *hostname,
-                                        struct ipmi_monitoring_ipmi_config *config)
+int
+ipmi_monitoring_ipmi_communication_init (ipmi_monitoring_ctx_t c,
+                                         const char *hostname,
+                                         struct ipmi_monitoring_ipmi_config *config)
 {
 
-  assert(c);
-  assert(c->magic == IPMI_MONITORING_MAGIC);
-  assert(!c->ipmi_ctx);
+  assert (c);
+  assert (c->magic == IPMI_MONITORING_MAGIC);
+  assert (!c->ipmi_ctx);
 
-  if (!(c->ipmi_ctx = ipmi_ctx_create()))
+  if (!(c->ipmi_ctx = ipmi_ctx_create ()))
     {
-      IPMI_MONITORING_DEBUG(("ipmi_device_create: %s", strerror(errno)));
+      IPMI_MONITORING_DEBUG (("ipmi_ctx_create: %s", strerror (errno)));
       c->errnum = IPMI_MONITORING_ERR_OUT_OF_MEMORY;
       goto cleanup;
     }
-  
-  if (!hostname 
-      || !strcasecmp(hostname, "localhost") 
-      || !strcmp(hostname, "127.0.0.1"))
+
+  if (!hostname
+      || !strcasecmp (hostname, "localhost")
+      || !strcmp (hostname, "127.0.0.1"))
     {
-      if (_inband_init(c, config) < 0)
+      if (_inband_init (c, config) < 0)
         goto cleanup;
     }
   else
     {
-      if (_outofband_init(c, hostname, config) < 0)
+      if (_outofband_init (c, hostname, config) < 0)
         goto cleanup;
     }
 
-  return 0;
+  return (0);
 
  cleanup:
-  _ipmi_communication_cleanup(c);
-  return -1;
+  _ipmi_communication_cleanup (c);
+  return (-1);
 }
 
 void
-ipmi_monitoring_ipmi_ctx_error_convert(ipmi_monitoring_ctx_t c)
+ipmi_monitoring_ipmi_ctx_error_convert (ipmi_monitoring_ctx_t c)
 {
-  if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_CONNECTION_TIMEOUT)
+  if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_CONNECTION_TIMEOUT)
     c->errnum = IPMI_MONITORING_ERR_CONNECTION_TIMEOUT;
-  else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_SESSION_TIMEOUT)
+  else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_SESSION_TIMEOUT)
     c->errnum = IPMI_MONITORING_ERR_SESSION_TIMEOUT;
-  else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE_INVALID_COMMAND
-           || ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE_REQUEST_DATA_INVALID
-           || ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE
-           || ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_IPMI_ERROR)
+  else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE
+           || ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_IPMI_ERROR)
     c->errnum = IPMI_MONITORING_ERR_IPMI_ERROR;
-  else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_BMC_BUSY)
+  else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_BMC_BUSY)
     c->errnum = IPMI_MONITORING_ERR_BMC_BUSY;
-  else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_PRIVILEGE_LEVEL_INSUFFICIENT)
+  else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_PRIVILEGE_LEVEL_INSUFFICIENT)
     c->errnum = IPMI_MONITORING_ERR_PRIVILEGE_LEVEL_INSUFFICIENT;
-  else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_OUT_OF_MEMORY)
+  else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_OUT_OF_MEMORY)
     c->errnum = IPMI_MONITORING_ERR_OUT_OF_MEMORY;
-  else if (ipmi_ctx_errnum(c->ipmi_ctx) == IPMI_ERR_SYSTEM_ERROR)
+  else if (ipmi_ctx_errnum (c->ipmi_ctx) == IPMI_ERR_SYSTEM_ERROR)
     c->errnum = IPMI_MONITORING_ERR_SYSTEM_ERROR;
   else
     c->errnum = IPMI_MONITORING_ERR_INTERNAL_ERROR;
 }
 
-int 
-ipmi_monitoring_ipmi_communication_cleanup(ipmi_monitoring_ctx_t c)
+int
+ipmi_monitoring_ipmi_communication_cleanup (ipmi_monitoring_ctx_t c)
 {
-  assert(c);
-  assert(c->magic == IPMI_MONITORING_MAGIC);
+  assert (c);
+  assert (c->magic == IPMI_MONITORING_MAGIC);
 
-  _ipmi_communication_cleanup(c);
-  return 0;
+  _ipmi_communication_cleanup (c);
+  return (0);
 }
