@@ -1,7 +1,7 @@
 /*****************************************************************************\
- *  $Id: ipmi_monitoring_sensor_reading.h,v 1.7 2008/03/28 00:14:44 chu11 Exp $
+ *  $Id: ipmi_monitoring_sensor_reading.h,v 1.13 2009/09/16 23:12:23 chu11 Exp $
  *****************************************************************************
- *  Copyright (C) 2007-2008 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2009 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2006-2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Albert Chu <chu11@llnl.gov>
@@ -29,11 +29,16 @@
 
 #include "ipmi_monitoring.h"
 
-int ipmi_monitoring_get_sensor_reading(ipmi_monitoring_ctx_t c, 
-                                       unsigned int sensor_reading_flags,
-                                       uint8_t *sdr_record,
-                                       unsigned int sdr_record_len,
-                                       unsigned int *sensor_groups,
-                                       unsigned int sensor_groups_len);
+int ipmi_monitoring_sensor_reading_init (ipmi_monitoring_ctx_t c);
+
+int ipmi_monitoring_sensor_reading_cleanup (ipmi_monitoring_ctx_t c);
+
+int ipmi_monitoring_get_sensor_reading (ipmi_monitoring_ctx_t c,
+                                        unsigned int sensor_reading_flags,
+                                        uint8_t *sdr_record,
+                                        unsigned int sdr_record_len,
+                                        unsigned int shared_sensor_number_offset,
+                                        unsigned int *sensor_types,
+                                        unsigned int sensor_types_len);
 
 #endif /* _IPMI_MONITORING_SENSOR_READING_H */
