@@ -1,5 +1,5 @@
-/* 
-   Copyright (C) 2003-2008 FreeIPMI Core Team
+/*
+   Copyright (C) 2003-2009 FreeIPMI Core Team
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.  
-*/
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
+ */
 
 #ifndef _IPMI_SENSOR_TYPES_SPEC_H
 #define _IPMI_SENSOR_TYPES_SPEC_H
@@ -23,9 +23,9 @@
 extern "C" {
 #endif
 
-#define IPMI_SENSOR_TYPE_RESERVED                            0x00 
-#define IPMI_SENSOR_TYPE_TEMPERATURE                         0x01 
-#define IPMI_SENSOR_TYPE_VOLTAGE                             0x02 
+#define IPMI_SENSOR_TYPE_RESERVED                            0x00
+#define IPMI_SENSOR_TYPE_TEMPERATURE                         0x01
+#define IPMI_SENSOR_TYPE_VOLTAGE                             0x02
 #define IPMI_SENSOR_TYPE_CURRENT                             0x03
 #define IPMI_SENSOR_TYPE_FAN                                 0x04
 #define IPMI_SENSOR_TYPE_PHYSICAL_SECURITY                   0x05
@@ -68,15 +68,18 @@ extern "C" {
 #define IPMI_SENSOR_TYPE_SESSION_AUDIT                       0x2A
 #define IPMI_SENSOR_TYPE_VERSION_CHANGE                      0x2B
 #define IPMI_SENSOR_TYPE_FRU_STATE                           0x2C
+#define IPMI_SENSOR_TYPE_OEM_MIN                             0xC0
+#define IPMI_SENSOR_TYPE_OEM_MAX                             0xFF
 
-#define IPMI_SENSOR_TYPE_VALID(__sensor_type) \
-        (((__sensor_type) >= IPMI_SENSOR_TYPE_RESERVED \
-          && (__sensor_type) <= IPMI_SENSOR_TYPE_FRU_STATE) ? 1 : 0)
+/* To avoid gcc warnings, add +1 in comparison */
+#define IPMI_SENSOR_TYPE_VALID(__sensor_type)              \
+  ((((__sensor_type) + 1) >= (IPMI_SENSOR_TYPE_RESERVED + 1)    \
+    && (__sensor_type) <= IPMI_SENSOR_TYPE_FRU_STATE) ? 1 : 0)
 
-/* "== 0xFF" to remove warnings */
+/* To avoid gcc warnings, subtract -1 in comparison */
 #define IPMI_SENSOR_TYPE_IS_OEM(__sensor_type) \
-        (((__sensor_type) >= 0xC0 \
-          && ((__sensor_type) <= 0xFE || (__sensor_type) == 0xFF)) ? 1 : 0)
+  (((__sensor_type) >= IPMI_SENSOR_TYPE_OEM_MIN \
+    && (((__sensor_type) - 1) <= (IPMI_SENSOR_TYPE_OEM_MAX - 1))) ? 1 : 0)
 
 extern const char *const ipmi_sensor_types[];
 extern const char *const ipmi_oem_sensor_type;
