@@ -1,19 +1,19 @@
-/* 
-   Copyright (C) 2003-2008 FreeIPMI Core Team
+/*
+  Copyright (C) 2003-2009 FreeIPMI Core Team
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2, or (at your option)
+  any later version.
 
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.  
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, write to the Free Software Foundation,
+  Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 */
 
 /* SMBIOS Reference Specification: map area between 000f0000 and
@@ -46,7 +46,9 @@
 #include "freeipmi/locate/ipmi-locate.h"
 #include "freeipmi/driver/ipmi-ssif-driver.h"
 
-#include "libcommon/ipmi-err-wrappers.h"
+#include "ipmi-locate-defs.h"
+#include "ipmi-locate-trace.h"
+#include "ipmi-locate-util.h"
 
 #include "freeipmi-portability.h"
 
@@ -54,33 +56,33 @@
    000fffff.  The IPMI Entry Structure begins on a 16-byte boundary,
    with a 4 byte "_SM_" signature.  */
 
-#define IPMI_SMBIOS_ENTRY_CSUM_OFFSET 	0x4
-#define IPMI_SMBIOS_ENTRY_LEN_OFFSET 	0x5
-#define IPMI_SMBIOS_ENTRY_ANCHOR_OFFSET 	0x10
+#define IPMI_SMBIOS_ENTRY_CSUM_OFFSET   0x4
+#define IPMI_SMBIOS_ENTRY_LEN_OFFSET    0x5
+#define IPMI_SMBIOS_ENTRY_ANCHOR_OFFSET         0x10
 #define IPMI_SMBIOS_ENTRY_ANCHOR_CSUM_OFFSET 0x15
 
-#define IPMI_SMBIOS_IPMI_DEV_INFO_SIG 		38
-#define IPMI_SMBIOS_IPMI_DEV_INFO_TYPE_OFFSET 	0x4
+#define IPMI_SMBIOS_IPMI_DEV_INFO_SIG           38
+#define IPMI_SMBIOS_IPMI_DEV_INFO_TYPE_OFFSET   0x4
 
-#define IPMI_SMBIOS_AREA_START 		0x000f0000
-#define IPMI_SMBIOS_AREA_END 		0x000fffff
-#define IPMI_SMBIOS_AREA_LEN 		((IPMI_SMBIOS_AREA_END - IPMI_SMBIOS_AREA_START) + 1)
-#define IPMI_SMBIOS_AREA_ALIGN 		16
-#define IPMI_SMBIOS_ENTRY_TLEN_OFFSET 	0x16
-#define IPMI_SMBIOS_ENTRY_PTR_OFFSET 	0x18
-#define IPMI_SMBIOS_DEV_INFO_LEN_OFFSET 	0x1
-#define IPMI_SMBIOS_IPMI_DEV_INFO_VER_OFFSET 	0x5
-#define IPMI_SMBIOS_IPMI_DEV_INFO_I2C_OFFSET 	0x6
-#define IPMI_SMBIOS_IPMI_DEV_INFO_NVSTOR_OFFSET 	0x7
-#define IPMI_SMBIOS_IPMI_DEV_INFO_ADDRESS_OFFSET 	0x8
-#define IPMI_SMBIOS_IPMI_DEV_INFO_MODIFIER_OFFSET 	0x10
-#define IPMI_SMBIOS_LSB_BIT 				4
-#define IPMI_SMBIOS_REGSPACING_SHIFT 		        6
-#define IPMI_SMBIOS_REGSPACING_MASK 			0x3
-#define IPMI_SMBIOS_INTINFO_PRESENT_BIT 		3
-#define IPMI_SMBIOS_INTINFO_POLARITY_BIT 		1
-#define IPMI_SMBIOS_INTINFO_TRIGGER_BIT 		0
-#define IPMI_SMBIOS_DEV_INFO_INTNUM_OFFSET 		0x11
+#define IPMI_SMBIOS_AREA_START          0x000f0000
+#define IPMI_SMBIOS_AREA_END            0x000fffff
+#define IPMI_SMBIOS_AREA_LEN            ((IPMI_SMBIOS_AREA_END - IPMI_SMBIOS_AREA_START) + 1)
+#define IPMI_SMBIOS_AREA_ALIGN          16
+#define IPMI_SMBIOS_ENTRY_TLEN_OFFSET   0x16
+#define IPMI_SMBIOS_ENTRY_PTR_OFFSET    0x18
+#define IPMI_SMBIOS_DEV_INFO_LEN_OFFSET         0x1
+#define IPMI_SMBIOS_IPMI_DEV_INFO_VER_OFFSET    0x5
+#define IPMI_SMBIOS_IPMI_DEV_INFO_I2C_OFFSET    0x6
+#define IPMI_SMBIOS_IPMI_DEV_INFO_NVSTOR_OFFSET         0x7
+#define IPMI_SMBIOS_IPMI_DEV_INFO_ADDRESS_OFFSET        0x8
+#define IPMI_SMBIOS_IPMI_DEV_INFO_MODIFIER_OFFSET       0x10
+#define IPMI_SMBIOS_LSB_BIT                             4
+#define IPMI_SMBIOS_REGSPACING_SHIFT                    6
+#define IPMI_SMBIOS_REGSPACING_MASK                     0x3
+#define IPMI_SMBIOS_INTINFO_PRESENT_BIT                 3
+#define IPMI_SMBIOS_INTINFO_POLARITY_BIT                1
+#define IPMI_SMBIOS_INTINFO_TRIGGER_BIT                 0
+#define IPMI_SMBIOS_DEV_INFO_INTNUM_OFFSET              0x11
 
 #define IPMI_SMBIOS_REGISTER_SPACING_1BYTE_BOUND    0x00
 #define IPMI_SMBIOS_REGISTER_SPACING_4BYTE_BOUND    0x01
@@ -89,65 +91,65 @@
 
 fiid_template_t tmpl_smbios_ipmi_device_info_record =
   {
-    {8, "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED}, 
-    {8, "comp_code", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED}, 
+    { 8, "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED | FIID_FIELD_MAKES_PACKET_SUFFICIENT},
+    { 8, "comp_code", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED | FIID_FIELD_MAKES_PACKET_SUFFICIENT},
     /* IPMI Device Information structure indicator. value = 38
        (Note this number is given in decimal) */
-    {8, "type", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED}, 
+    { 8, "type", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     /* Length of the structure, a minimum of 10h (for
        full IPMI address description, this is a minimum
        of 12h) */
-    {8, "length", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED}, 
-    {16, "handle", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED}, 
+    { 8, "length", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 16, "handle", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     /* Baseboard Management Controller (BMC)
        interface type, see Table C1-2, Interface Type
        field values. */
-    {8, "interface_type", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED}, 
+    { 8, "interface_type", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     /* Somewhat mis-named. Actually identifies the
        IPMI Specification Version, in BCD format, to
        which the BMC was designed. Bits 7:4 hold the
-       most significant digit of the version, 
+       most significant digit of the version,
        while bits 3:0 hold the least significant bits,
        e.g. a value of 15h indicates version 1.5. */
-    {4, "ipmi_spec_revision.minor", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
-    {4, "ipmi_spec_revision.major", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 4, "ipmi_spec_revision.minor", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 4, "ipmi_spec_revision.major", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     /* The slave address on the I2C bus of this BMC. */
-    {8, "i2c_slave_address", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED}, 
+    { 8, "i2c_slave_address", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     /* Bus id of the NV storage device. If no storage
        device exists for this BMC, the field is set to
        0FFh. */
-    {8, "nv_storage_device_address", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
-    {1, "base_address.io_mapped_or_mem_mapped", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED}, 
+    { 8, "nv_storage_device_address", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 1, "base_address.io_mapped_or_mem_mapped", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     /* Identifies the base address (either memory-
        mapped or I/O) of the BMC. If the least-
        significant bit of the field is a 1, the address is
        in I/O space; otherwise, the address is
        memory-mapped. Refer to the IPMI Interface
        Specification for usage details. */
-    {15, "base_address", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 15, "base_address", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     /* bit 0 - Interrupt Trigger Mode.
        1b = level, 0b = edge. */
-    {1, "interrupt_trigger_mode", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 1, "interrupt_trigger_mode", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     /* bit 1 - Interrupt Polarity.
        1b = active high, 0b = active low. */
-    {1, "interrupt_polarity", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED}, 
-    /* bit 2 - reserved. 
+    { 1, "interrupt_polarity", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    /* bit 2 - reserved.
        Return as 0b. */
-    {1, "base_address_modifier_interrupt_info.reserved1", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED}, 
+    { 1, "base_address_modifier_interrupt_info.reserved1", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     /* Interrupt Info
        Identifies the type and polarity of the
        interrupt associated with the IPMI system
        interface, if any.
        bit 3 - 1b = interrupt info specified
        0b = interrupt info not specified */
-    {1, "interrupt_info", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED}, 
+    { 1, "interrupt_info", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     /* bit 4 - LS-bit for addresses
        0b = Address bit 0 = 0b
        1b = Address bit 0 = 1b */
-    {1, "ls_bit_for_addresses", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
-    /* bit 5 - reserved. 
+    { 1, "ls_bit_for_addresses", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    /* bit 5 - reserved.
        Return as 0b. */
-    {1, "base_address_modifier_interrupt_info.reserved2", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED}, 
+    { 1, "base_address_modifier_interrupt_info.reserved2", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     /* bit 7:6 - Register spacing
        00b = interface registers are on
        successive byte boundaries
@@ -156,22 +158,22 @@ fiid_template_t tmpl_smbios_ipmi_device_info_record =
        10b = interface registers are on 16-
        byte boundaries
        11b = reserved */
-    {2, "register_spacing", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED}, 
+    { 2, "register_spacing", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     /* Interrupt number for IPMI System Interface.
        00h = unspecified / unsupported */
-    {8, "interrupt_number", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED}, 
-    {0, "", 0}
+    { 8, "interrupt_number", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 0, "", 0}
   };
 
 static int
 _ipmi_smbios_register_spacing (uint8_t register_spacing_boundary, uint8_t *register_spacing)
 {
-  assert (register_spacing 
-          && (register_spacing_boundary == IPMI_SMBIOS_REGISTER_SPACING_1BYTE_BOUND
-              || register_spacing_boundary == IPMI_SMBIOS_REGISTER_SPACING_4BYTE_BOUND
-              || register_spacing_boundary == IPMI_SMBIOS_REGISTER_SPACING_16BYTE_BOUND
-              || register_spacing_boundary == IPMI_SMBIOS_REGISTER_SPACING_RESERVED));
-  
+  assert (register_spacing);
+  assert (register_spacing_boundary == IPMI_SMBIOS_REGISTER_SPACING_1BYTE_BOUND
+          || register_spacing_boundary == IPMI_SMBIOS_REGISTER_SPACING_4BYTE_BOUND
+          || register_spacing_boundary == IPMI_SMBIOS_REGISTER_SPACING_16BYTE_BOUND
+          || register_spacing_boundary == IPMI_SMBIOS_REGISTER_SPACING_RESERVED);
+
   switch (register_spacing_boundary)
     {
     case IPMI_SMBIOS_REGISTER_SPACING_1BYTE_BOUND:
@@ -187,7 +189,8 @@ _ipmi_smbios_register_spacing (uint8_t register_spacing_boundary, uint8_t *regis
     default:
       *register_spacing = 0;
       /* Should not reach */
-      ERR_EINVAL(0);
+      SET_ERRNO (EINVAL);
+      return (-1);
     }
 }
 
@@ -200,9 +203,9 @@ _ipmi_smbios_register_spacing (uint8_t register_spacing_boundary, uint8_t *regis
    sigp = points to start of purported SMBIOS entry structure
    RETURNS:
    0 = not really a SMBIOS entry structure
-   1 = yes, a real SMBIOS entry structure */ 
+   1 = yes, a real SMBIOS entry structure */
 static int
-_is_ipmi_entry (int *locate_errnum,
+_is_ipmi_entry (ipmi_locate_ctx_t ctx,
                 uint8_t* sigp)
 {
   static const char smbios_entry_sig[4] = { '_', 'S', 'M', '_' };
@@ -212,11 +215,12 @@ _is_ipmi_entry (int *locate_errnum,
   uint8_t entry_len;
   uint8_t* bp;
 
-  assert(locate_errnum);
-  assert(sigp);
+  assert (ctx);
+  assert (ctx->magic == IPMI_LOCATE_CTX_MAGIC);
+  assert (sigp);
 
   if (memcmp (sigp, smbios_entry_sig, sizeof (smbios_entry_sig)) != 0)
-    return 0;
+    return (0);
 
   entry_len = sigp[IPMI_SMBIOS_ENTRY_LEN_OFFSET];
 
@@ -226,14 +230,14 @@ _is_ipmi_entry (int *locate_errnum,
     csum_computed = (csum_computed + (*bp)) % (1 << CHAR_BIT);
 
   if (memcmp (sigp + IPMI_SMBIOS_ENTRY_ANCHOR_OFFSET, smbios_entry_anchor,
-	      sizeof (smbios_entry_anchor)) != 0)
+              sizeof (smbios_entry_anchor)) != 0)
     return (0);
 
   csum_given = sigp[IPMI_SMBIOS_ENTRY_ANCHOR_CSUM_OFFSET];
   csum_computed = 0;
   for (bp = sigp + IPMI_SMBIOS_ENTRY_ANCHOR_CSUM_OFFSET; bp < sigp + entry_len; bp++)
     csum_computed = (csum_computed + (*bp)) % (1 << CHAR_BIT);
-    
+
   return (1);
 }
 
@@ -246,21 +250,22 @@ _is_ipmi_entry (int *locate_errnum,
    0 = not a IPMI device info structure for TYPE
    1 = yes, IPMI device info structure for TYPE */
 static int
-_is_ipmi_dev_info (int *locate_errnum,
-                   ipmi_interface_type_t type, 
+_is_ipmi_dev_info (ipmi_locate_ctx_t ctx,
+                   ipmi_interface_type_t type,
                    uint8_t* dev_info_p)
 {
-  assert(locate_errnum);
-  assert(IPMI_INTERFACE_TYPE_VALID(type));
-  assert(dev_info_p);
+  assert (ctx);
+  assert (ctx->magic == IPMI_LOCATE_CTX_MAGIC);
+  assert (IPMI_INTERFACE_TYPE_VALID (type));
+  assert (dev_info_p);
 
   if (*dev_info_p != IPMI_SMBIOS_IPMI_DEV_INFO_SIG)
-    return 0;
+    return (0);
 
   if (dev_info_p[IPMI_SMBIOS_IPMI_DEV_INFO_TYPE_OFFSET] != type)
-    return 0;
+    return (0);
 
-  return 1;
+  return (1);
 }
 
 /* _map_physmem
@@ -272,33 +277,49 @@ _is_ipmi_dev_info (int *locate_errnum,
    RETURNS:
    pointer to area of physical memory at physmem */
 static uint8_t*
-_map_physmem (int *locate_errnum,
-              uint32_t physaddress, 
-              size_t len, 
-              void** startp, 
+_map_physmem (ipmi_locate_ctx_t ctx,
+              uint32_t physaddress,
+              size_t len,
+              void** startp,
               size_t* totallen)
 {
   uint32_t startaddress;
   uint32_t pad;
   int mem_fd = -1;
+  uint8_t *rv = NULL;
 
-  assert(locate_errnum);
-  assert(startp && totallen);
+  assert (ctx);
+  assert (ctx->magic == IPMI_LOCATE_CTX_MAGIC);
+  assert (startp);
+  assert (totallen);
 
-  LOCATE_ERR_CLEANUP(!((mem_fd = open ("/dev/mem", O_RDONLY|O_SYNC)) < 0));
+  if ((mem_fd = open ("/dev/mem", O_RDONLY|O_SYNC)) < 0)
+    {
+      LOCATE_ERRNO_TO_LOCATE_ERRNUM (ctx, errno);
+      goto cleanup;
+    }
 
   pad = physaddress % sysconf (_SC_PAGESIZE);
   startaddress = physaddress - pad;
   *totallen = len + pad;
 
-  LOCATE_ERR_CLEANUP(!((*startp = mmap (NULL, *totallen, PROT_READ, MAP_PRIVATE, mem_fd, startaddress)) == MAP_FAILED));
-  
-  close (mem_fd);
-  return ((uint8_t*)(*startp) + pad);
-  
+  if ((*startp = mmap (NULL,
+                       *totallen,
+                       PROT_READ,
+                       MAP_PRIVATE,
+                       mem_fd,
+                       startaddress)) == MAP_FAILED)
+    {
+      LOCATE_ERRNO_TO_LOCATE_ERRNUM (ctx, errno);
+      goto cleanup;
+    }
+
+  rv = (uint8_t*)(*startp) + pad;
+
  cleanup:
+  /* ignore potential error, cleanup path */
   close (mem_fd);
-  return NULL;	  
+  return (rv);
 }
 
 /* _copy_ipmi_dev_info
@@ -308,30 +329,31 @@ _map_physmem (int *locate_errnum,
    pointer to the device info structure in heap (caller responsible
    for freeing */
 static uint8_t*
-_copy_ipmi_dev_info (int *locate_errnum,
+_copy_ipmi_dev_info (ipmi_locate_ctx_t ctx,
                      ipmi_interface_type_t type)
 {
   uint8_t* result = NULL;
   void* map_entry = NULL;
   size_t map_entry_len;
-  uint8_t* pmem_entry; 
+  uint8_t* pmem_entry;
   uint8_t* rv = NULL;
   uint8_t* sigp;
   int flag;
 
-  assert(locate_errnum);
-  assert(IPMI_INTERFACE_TYPE_VALID(type));
+  assert (ctx);
+  assert (ctx->magic == IPMI_LOCATE_CTX_MAGIC);
+  assert (IPMI_INTERFACE_TYPE_VALID (type));
 
-  if (!(pmem_entry = _map_physmem (locate_errnum,
-                                   IPMI_SMBIOS_AREA_START, 
-                                   IPMI_SMBIOS_AREA_LEN, 
-                                   &map_entry, 
+  if (!(pmem_entry = _map_physmem (ctx,
+                                   IPMI_SMBIOS_AREA_START,
+                                   IPMI_SMBIOS_AREA_LEN,
+                                   &map_entry,
                                    &map_entry_len)))
     goto cleanup;
 
   for (sigp = pmem_entry; sigp - pmem_entry < IPMI_SMBIOS_AREA_LEN; sigp += IPMI_SMBIOS_AREA_ALIGN)
     {
-      if ((flag = _is_ipmi_entry (locate_errnum, sigp)) < 0)
+      if ((flag = _is_ipmi_entry (ctx, sigp)) < 0)
         goto cleanup;
 
       if (flag)
@@ -343,27 +365,31 @@ _copy_ipmi_dev_info (int *locate_errnum,
           uint8_t* dev_info_p;
           size_t size;
           uint8_t* var_info_p;
-          
+
           s_table_len = *(uint16_t*)(sigp + IPMI_SMBIOS_ENTRY_TLEN_OFFSET);
-          if (!(pmem_table = _map_physmem (locate_errnum,
-                                           *(uint32_t*)(sigp + IPMI_SMBIOS_ENTRY_PTR_OFFSET), 
+          if (!(pmem_table = _map_physmem (ctx,
+                                           *(uint32_t*)(sigp + IPMI_SMBIOS_ENTRY_PTR_OFFSET),
                                            s_table_len,
-                                           &map_table, 
+                                           &map_table,
                                            &map_table_len)))
             goto cleanup;
-          
+
           dev_info_p = pmem_table;
           size = dev_info_p[IPMI_SMBIOS_DEV_INFO_LEN_OFFSET];
           while (dev_info_p - pmem_table < s_table_len)
             {
-              if ((flag = _is_ipmi_dev_info (locate_errnum, 
-                                             type, 
+              if ((flag = _is_ipmi_dev_info (ctx,
+                                             type,
                                              dev_info_p)) < 0)
                 goto cleanup;
 
               if (flag)
                 {
-                  LOCATE_ERR_OUT_OF_MEMORY_CLEANUP ((result = malloc (size)));
+                  if (!(result = malloc (size)))
+                    {
+                      LOCATE_SET_ERRNUM (ctx, IPMI_LOCATE_ERR_OUT_OF_MEMORY);
+                      goto cleanup;
+                    }
                   memcpy (result, dev_info_p, size);
                   rv = result;
                   break;
@@ -374,6 +400,7 @@ _copy_ipmi_dev_info (int *locate_errnum,
               dev_info_p = var_info_p + 2;
               size = dev_info_p[IPMI_SMBIOS_DEV_INFO_LEN_OFFSET];
             }
+          /* ignore potential error, just return result */
           munmap (map_table, map_table_len);
         }
 
@@ -381,8 +408,9 @@ _copy_ipmi_dev_info (int *locate_errnum,
         break;
     }
 
-  LOCATE_ERRNUM_SET(IPMI_LOCATE_ERR_SYSTEM_ERROR);
+  LOCATE_SET_ERRNUM (ctx, IPMI_LOCATE_ERR_SYSTEM_ERROR);
  cleanup:
+  /* ignore potential error, just return result */
   if (map_entry)
     munmap (map_entry, map_entry_len);
   return (rv);
@@ -395,10 +423,10 @@ _copy_ipmi_dev_info (int *locate_errnum,
    pinfo = pointer to information structure filled in by this function
    RETURNS:
    0 on success, -1 on error */
-static int
-_ipmi_locate_smbios_get_device_info (int *locate_errnum,
-                                     ipmi_interface_type_t type,
-                                     struct ipmi_locate_info *info)
+int
+ipmi_locate_smbios_get_device_info (ipmi_locate_ctx_t ctx,
+                                    ipmi_interface_type_t type,
+                                    struct ipmi_locate_info *info)
 {
   uint8_t* bufp = NULL;
   uint8_t version;
@@ -406,19 +434,27 @@ _ipmi_locate_smbios_get_device_info (int *locate_errnum,
   uint64_t strobed;
   struct ipmi_locate_info linfo;
 
-  assert(locate_errnum);
+  if (!ctx || ctx->magic != IPMI_LOCATE_CTX_MAGIC)
+    {
+      ERR_TRACE (ipmi_locate_ctx_errormsg (ctx), ipmi_locate_ctx_errnum (ctx));
+      return (-1);
+    }
 
-  LOCATE_ERR_PARAMETERS(IPMI_INTERFACE_TYPE_VALID(type) && info);
+  if (!IPMI_INTERFACE_TYPE_VALID (type) || !info)
+    {
+      LOCATE_SET_ERRNUM (ctx, IPMI_LOCATE_ERR_PARAMETERS);
+      return (-1);
+    }
 
-  memset(&linfo, '\0', sizeof(struct ipmi_locate_info));
+  memset (&linfo, '\0', sizeof (struct ipmi_locate_info));
   linfo.interface_type = type;
   if (type == IPMI_INTERFACE_SSIF)
     {
-      strncpy(linfo.driver_device, IPMI_DEFAULT_I2C_DEVICE, IPMI_LOCATE_PATH_MAX);
+      strncpy (linfo.driver_device, IPMI_DEFAULT_I2C_DEVICE, IPMI_LOCATE_PATH_MAX);
       linfo.driver_device[IPMI_LOCATE_PATH_MAX - 1] = '\0';
     }
 
-  if (!(bufp = _copy_ipmi_dev_info (locate_errnum, type)))
+  if (!(bufp = _copy_ipmi_dev_info (ctx, type)))
     goto cleanup;
 
   linfo.locate_driver_type = IPMI_LOCATE_DRIVER_SMBIOS;
@@ -428,7 +464,11 @@ _ipmi_locate_smbios_get_device_info (int *locate_errnum,
   linfo.ipmi_version_minor = version & 0xf;
 
   linfo.interface_type = bufp[IPMI_SMBIOS_IPMI_DEV_INFO_TYPE_OFFSET];
-  LOCATE_ERR_SYSTEM_ERROR_CLEANUP(linfo.interface_type == type);
+  if (linfo.interface_type != type)
+    {
+      LOCATE_SET_ERRNUM (ctx, IPMI_LOCATE_ERR_SYSTEM_ERROR);
+      goto cleanup;
+    }
 
   strobed = address = *(uint64_t*)(bufp+IPMI_SMBIOS_IPMI_DEV_INFO_ADDRESS_OFFSET);
   if (bufp[IPMI_SMBIOS_DEV_INFO_LEN_OFFSET] >= IPMI_SMBIOS_IPMI_DEV_INFO_MODIFIER_OFFSET)
@@ -442,7 +482,7 @@ _ipmi_locate_smbios_get_device_info (int *locate_errnum,
       strobed = (strobed & ~1) | lsb;
 
       register_spacing_boundary = (modifier >> IPMI_SMBIOS_REGSPACING_SHIFT) & IPMI_SMBIOS_REGSPACING_MASK;
-      if (_ipmi_smbios_register_spacing (register_spacing_boundary, 
+      if (_ipmi_smbios_register_spacing (register_spacing_boundary,
                                          &linfo.register_spacing) < 0)
         goto cleanup;
     }
@@ -455,41 +495,23 @@ _ipmi_locate_smbios_get_device_info (int *locate_errnum,
   else
     {
       if ((address & 1) != 0)
-	{
-	  linfo.address_space_id = IPMI_ADDRESS_SPACE_ID_SYSTEM_IO;
-	  linfo.driver_address = strobed;
-	}
+        {
+          linfo.address_space_id = IPMI_ADDRESS_SPACE_ID_SYSTEM_IO;
+          linfo.driver_address = strobed;
+        }
       else
-	{
-	  linfo.address_space_id = IPMI_ADDRESS_SPACE_ID_SYSTEM_MEMORY;
-	  linfo.driver_address = strobed;
-	}
+        {
+          linfo.address_space_id = IPMI_ADDRESS_SPACE_ID_SYSTEM_MEMORY;
+          linfo.driver_address = strobed;
+        }
     }
 
   free (bufp);
-  memcpy(info, &linfo, sizeof(struct ipmi_locate_info));
+  memcpy (info, &linfo, sizeof (struct ipmi_locate_info));
   return (0);
 
  cleanup:
   if (bufp)
-    free(bufp);
+    free (bufp);
   return (-1);
 }
-
-int
-ipmi_locate_smbios_get_device_info (ipmi_interface_type_t type,
-                                    struct ipmi_locate_info *info)
-{
-  int errnum;
-  int *locate_errnum;
-
-  locate_errnum = &errnum;
-
-  if (_ipmi_locate_smbios_get_device_info(&errnum, type, info) < 0)
-    {
-      if (!errnum)
-        LOCATE_ERRNUM_SET(IPMI_LOCATE_ERR_INTERNAL_ERROR);
-      return errnum;
-    }
-  return 0;
-}
